<div xmlns="http://www.w3.org/1999/xhtml" xmlns:html="http://www.w3.org/1999/xhtml" xmlns:pm="http://www.polymake.org/ns/docs#3" id="content">
  <h1>application: group</h1>
  <div class="descr">
    <p> The application group provides basic functionality for working with permutation groups. </p>
    <p> An object of type <a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a> records the abstract properties of the groups 
 that do not depend on any particular representation, such as <a href="#group__ORDER__138" onclick="unfold('span:group__ORDER__138');">ORDER</a>,
 <a href="#group__CHARACTER_TABLE__148" onclick="unfold('span:group__CHARACTER_TABLE__148');">CHARACTER_TABLE</a> and <a href="#group__CONJUGACY_CLASS_SIZES__140" onclick="unfold('span:group__CONJUGACY_CLASS_SIZES__140');">CONJUGACY_CLASS_SIZES</a>.</p>
    <p> Moreover, it can contain several subobjects of type <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a>, <a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a> 
 or <a href="#group__ImplicitActionOnSets__18" onclick="unfold('span:group__ImplicitActionOnSets__18');">ImplicitActionOnSets</a> that encode representations of the group. (We use the terms <em class="param">action</em>
 and <em class="param">representation</em> interchangeably). </p>
    <p> If the group object is not contained inside a <a href="polytope.html#polytope__Cone__21" onclick="unfold('span:polytope__Cone__21');">polytope::Cone</a> or <a href="polytope.html#polytope__Polytope__20" onclick="unfold('span:polytope__Polytope__20');">polytope::Polytope</a>,
 the representation in question is encoded as a <a href="#group__PERMUTATION_ACTION__142" onclick="unfold('span:group__PERMUTATION_ACTION__142');">Group::PERMUTATION_ACTION</a>, <a href="#group__SET_ACTION__139" onclick="unfold('span:group__SET_ACTION__139');">Group::SET_ACTION</a> or 
 <a href="#group__IMPLICIT_SET_ACTION__152" onclick="unfold('span:group__IMPLICIT_SET_ACTION__152');">Group::IMPLICIT_SET_ACTION</a>, otherwise it may be encoded more specifically as a RAY_ACTION, FACET_ACTION,
 COORDINATE_ACTION, etc. </p>
    <p> Different representations of the same group are convertible among each other either via specific rules, 
 or by using the function <a href="#group__induced_action__70" onclick="unfold('span:group__induced_action__70');">induced_action</a>, for example.</p>
  </div>
  <b>imports from: </b>
  <a href="common.html">common</a>
  <br/>
  <div class="level2">
    <h2>
      <b>Objects</b>
    </h2>
    <ul class="unfoldable">
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Action__16" onclick="swap_content('span:group__Action__16'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__Action__16" onclick="swap_content('span:group__Action__16'); return false;">
                  <span class="object">Action</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Action__16" class="foldit">
              <div class="descr">
                <p> parametrized object used for encoding group actions (representations).</p>
                <p> <em class="param">GeneratorType</em> is Array&lt;Int&gt;      for permutation groups,
                   or Matrix&lt;Scalar&gt;  for matrix groups.</p>
                <p> <em class="param">DomainType</em> is Int                for permutation groups,
                   Vector&lt;Scalar&gt;     for matrix groups acting on facets or vertices,
                   Set&lt;Int&gt; or Bitset for groups acting on simplices,
                   IncidenceMatrix    for groups acting on (maximal) cones of a fan</p>
                <p> <em class="param">OrbitGeneratorScalarType</em> is the type of the entries of vectors that generate a geometric orbit; default Rational</p>
              </div>
              <div class="level3"/>
              <h4>Properties of Action</h4>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__Symmetry__98" onclick="swap_content('span:group__Symmetry__98'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <div class="category">
                        <h3>
                          <a href="#" class="javalink" id="group__Symmetry__98" onclick="swap_content('span:group__Symmetry__98'); return false;">
                            <span class="category">Symmetry</span>
                          </a>
                        </h3>
                      </div>
                      <div style="display: inline" id="span:group__Symmetry__98" class="foldit">
                        <div class="descr">
                          <p> These properties capture information of the object that is concerned with the action of permutation groups.</p>
                        </div>
                        <ul class="unfoldable">
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ALL_GROUP_ELEMENTS__112" onclick="swap_content('span:group__ALL_GROUP_ELEMENTS__112'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ALL_GROUP_ELEMENTS__112" onclick="swap_content('span:group__ALL_GROUP_ELEMENTS__112'); return false;"><b>ALL_GROUP_ELEMENTS</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__ALL_GROUP_ELEMENTS__112" class="foldit">
                                  <div class="descr">
                                    <p> All elements of the group, as expressed in the present action
 Notice that this is a temporary property; it will not be stored in any file.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__CHARACTER__119" onclick="swap_content('span:group__CHARACTER__119'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__CHARACTER__119" onclick="swap_content('span:group__CHARACTER__119'); return false;"><b>CHARACTER</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;QuadraticExtension&lt;Rational&gt;&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__CHARACTER__119" class="foldit">
                                  <div class="descr">
                                    <p> The character of the action. The ordering corresponds to the
 columns of the CHARACTER_TABLE</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__CONJUGACY_CLASSES__107" onclick="swap_content('span:group__CONJUGACY_CLASSES__107'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__CONJUGACY_CLASSES__107" onclick="swap_content('span:group__CONJUGACY_CLASSES__107'); return false;"><b>CONJUGACY_CLASSES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__CONJUGACY_CLASSES__107" class="foldit">
                                  <div class="descr">
                                    <p> The conjugacy classes themselves</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__CONJUGACY_CLASS_REPRESENTATIVES__129" onclick="swap_content('span:group__CONJUGACY_CLASS_REPRESENTATIVES__129'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__CONJUGACY_CLASS_REPRESENTATIVES__129" onclick="swap_content('span:group__CONJUGACY_CLASS_REPRESENTATIVES__129'); return false;"><b>CONJUGACY_CLASS_REPRESENTATIVES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__CONJUGACY_CLASS_REPRESENTATIVES__129" class="foldit">
                                  <div class="descr">
                                    <p> A set of representatives for each conjugacy class.
 The order of these representatives must agree with the implicit
 order of the columns of the <a href="#group__CHARACTER_TABLE__148" onclick="unfold('span:group__CHARACTER_TABLE__148');">CHARACTER_TABLE</a>.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__DEGREE__108" onclick="swap_content('span:group__DEGREE__108'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__DEGREE__108" onclick="swap_content('span:group__DEGREE__108'); return false;"><b>DEGREE</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__DEGREE__108" class="foldit">
                                  <div class="descr">
                                    <p> The degree of the representation. For permutation groups,
 this is the number of permuted indices, for matrix groups
 it is the dimension of the vector space the group acts on</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__DOMAIN_NAME__101" onclick="swap_content('span:group__DOMAIN_NAME__101'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__DOMAIN_NAME__101" onclick="swap_content('span:group__DOMAIN_NAME__101'); return false;"><b>DOMAIN_NAME</b>:
		</a>
                                <a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">common::String</a>
                                <br/>
                                <div style="display: inline" id="span:group__DOMAIN_NAME__101" class="foldit">
                                  <div class="descr">
                                    <p> the name of the property that we act on, for example MAX_INTERIOR_SIMPLICES or INTERIOR_RIDGES</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__EQUATIONS_GENERATORS__114" onclick="swap_content('span:group__EQUATIONS_GENERATORS__114'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__EQUATIONS_GENERATORS__114" onclick="swap_content('span:group__EQUATIONS_GENERATORS__114'); return false;"><b>EQUATIONS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__EQUATIONS_GENERATORS__114" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for equations, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__EXPLICIT_ORBIT_REPRESENTATIVES__121" onclick="swap_content('span:group__EXPLICIT_ORBIT_REPRESENTATIVES__121'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__EXPLICIT_ORBIT_REPRESENTATIVES__121" onclick="swap_content('span:group__EXPLICIT_ORBIT_REPRESENTATIVES__121'); return false;"><b>EXPLICIT_ORBIT_REPRESENTATIVES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__EXPLICIT_ORBIT_REPRESENTATIVES__121" class="foldit">
                                  <div class="descr">
                                    <p> the representatives of orbits explicitly, not via their indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX__102" onclick="swap_content('span:group__EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX__102'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX__102" onclick="swap_content('span:group__EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX__102'); return false;"><b>EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__EXPLICIT_ORBIT_REPRESENTATIVE_MATRIX__102" class="foldit">
                                  <div class="descr">
                                    <p> the representatives of orbits explicitly, not via their indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__FACETS_GENERATORS__132" onclick="swap_content('span:group__FACETS_GENERATORS__132'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__FACETS_GENERATORS__132" onclick="swap_content('span:group__FACETS_GENERATORS__132'); return false;"><b>FACETS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__FACETS_GENERATORS__132" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for facets, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__GENERATORS__127" onclick="swap_content('span:group__GENERATORS__127'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__GENERATORS__127" onclick="swap_content('span:group__GENERATORS__127'); return false;"><b>GENERATORS</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__GENERATORS__127" class="foldit">
                                  <div class="descr">
                                    <p> The generators of the group action</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__IMAGES__116" onclick="swap_content('span:group__IMAGES__116'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__IMAGES__116" onclick="swap_content('span:group__IMAGES__116'); return false;"><b>IMAGES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array</a>
                                <br/>
                                <div style="display: inline" id="span:group__IMAGES__116" class="foldit">
                                  <div class="descr">
                                    <p> The images of all domain elements under each group element: [ [ g(x) for x in D ] for g in G ]</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INDEX_OF__134" onclick="swap_content('span:group__INDEX_OF__134'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INDEX_OF__134" onclick="swap_content('span:group__INDEX_OF__134'); return false;"><b>INDEX_OF</b>:
		</a>
                                <a href="common.html#common__HashMap__277" onclick="unfold('span:common__HashMap__277');">common::HashMap</a>
                                <br/>
                                <div style="display: inline" id="span:group__INDEX_OF__134" class="foldit">
                                  <div class="descr">
                                    <p> The map giving the index of each group element
 This is a temporary property; it will not be stored in any file.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INDUCED_FROM__122" onclick="swap_content('span:group__INDUCED_FROM__122'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INDUCED_FROM__122" onclick="swap_content('span:group__INDUCED_FROM__122'); return false;"><b>INDUCED_FROM</b>:
		</a>
                                <a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">common::String</a>
                                <br/>
                                <div style="display: inline" id="span:group__INDUCED_FROM__122" class="foldit">
                                  <div class="descr">
                                    <p> the name of a different action that this action is induced from</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INEQUALITIES_GENERATORS__104" onclick="swap_content('span:group__INEQUALITIES_GENERATORS__104'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INEQUALITIES_GENERATORS__104" onclick="swap_content('span:group__INEQUALITIES_GENERATORS__104'); return false;"><b>INEQUALITIES_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__INEQUALITIES_GENERATORS__104" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for inequalities, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INPUT_LINEALITY_GENERATORS__109" onclick="swap_content('span:group__INPUT_LINEALITY_GENERATORS__109'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INPUT_LINEALITY_GENERATORS__109" onclick="swap_content('span:group__INPUT_LINEALITY_GENERATORS__109'); return false;"><b>INPUT_LINEALITY_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__INPUT_LINEALITY_GENERATORS__109" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for input lineality, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INPUT_RAYS_GENERATORS__118" onclick="swap_content('span:group__INPUT_RAYS_GENERATORS__118'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INPUT_RAYS_GENERATORS__118" onclick="swap_content('span:group__INPUT_RAYS_GENERATORS__118'); return false;"><b>INPUT_RAYS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__INPUT_RAYS_GENERATORS__118" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for input rays, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__IRREDUCIBLE_DECOMPOSITION__113" onclick="swap_content('span:group__IRREDUCIBLE_DECOMPOSITION__113'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__IRREDUCIBLE_DECOMPOSITION__113" onclick="swap_content('span:group__IRREDUCIBLE_DECOMPOSITION__113'); return false;"><b>IRREDUCIBLE_DECOMPOSITION</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__IRREDUCIBLE_DECOMPOSITION__113" class="foldit">
                                  <div class="descr">
                                    <p> The multiplicities of each irreducible representation in this action.
 The ordering corresponds to the rows of the CHARACTER_TABLE</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__LINEALITY_SPACE_GENERATORS__103" onclick="swap_content('span:group__LINEALITY_SPACE_GENERATORS__103'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__LINEALITY_SPACE_GENERATORS__103" onclick="swap_content('span:group__LINEALITY_SPACE_GENERATORS__103'); return false;"><b>LINEALITY_SPACE_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__LINEALITY_SPACE_GENERATORS__103" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for input lineality, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__MAXIMAL_CONES_GENERATORS__123" onclick="swap_content('span:group__MAXIMAL_CONES_GENERATORS__123'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__MAXIMAL_CONES_GENERATORS__123" onclick="swap_content('span:group__MAXIMAL_CONES_GENERATORS__123'); return false;"><b>MAXIMAL_CONES_GENERATORS</b>:
		</a>
                                <a href="common.html#common__IncidenceMatrix__280" onclick="unfold('span:common__IncidenceMatrix__280');">common::IncidenceMatrix&lt;NonSymmetric&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__MAXIMAL_CONES_GENERATORS__123" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for the maximal cones of a fan, stored in terms of indices of vertex generators.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_EQUATIONS_GENERATORS__125" onclick="swap_content('span:group__N_EQUATIONS_GENERATORS__125'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_EQUATIONS_GENERATORS__125" onclick="swap_content('span:group__N_EQUATIONS_GENERATORS__125'); return false;"><b>N_EQUATIONS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_EQUATIONS_GENERATORS__125" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_FACETS_GENERATORS__133" onclick="swap_content('span:group__N_FACETS_GENERATORS__133'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_FACETS_GENERATORS__133" onclick="swap_content('span:group__N_FACETS_GENERATORS__133'); return false;"><b>N_FACETS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_FACETS_GENERATORS__133" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_INEQUALITIES_GENERATORS__106" onclick="swap_content('span:group__N_INEQUALITIES_GENERATORS__106'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_INEQUALITIES_GENERATORS__106" onclick="swap_content('span:group__N_INEQUALITIES_GENERATORS__106'); return false;"><b>N_INEQUALITIES_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_INEQUALITIES_GENERATORS__106" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_INPUT_LINEALITY_GENERATORS__117" onclick="swap_content('span:group__N_INPUT_LINEALITY_GENERATORS__117'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_INPUT_LINEALITY_GENERATORS__117" onclick="swap_content('span:group__N_INPUT_LINEALITY_GENERATORS__117'); return false;"><b>N_INPUT_LINEALITY_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_INPUT_LINEALITY_GENERATORS__117" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_INPUT_RAYS_GENERATORS__105" onclick="swap_content('span:group__N_INPUT_RAYS_GENERATORS__105'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_INPUT_RAYS_GENERATORS__105" onclick="swap_content('span:group__N_INPUT_RAYS_GENERATORS__105'); return false;"><b>N_INPUT_RAYS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_INPUT_RAYS_GENERATORS__105" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_LINEALITY_SPACE_GENERATORS__115" onclick="swap_content('span:group__N_LINEALITY_SPACE_GENERATORS__115'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_LINEALITY_SPACE_GENERATORS__115" onclick="swap_content('span:group__N_LINEALITY_SPACE_GENERATORS__115'); return false;"><b>N_LINEALITY_SPACE_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_LINEALITY_SPACE_GENERATORS__115" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_MAXIMAL_CONES_GENERATORS__131" onclick="swap_content('span:group__N_MAXIMAL_CONES_GENERATORS__131'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_MAXIMAL_CONES_GENERATORS__131" onclick="swap_content('span:group__N_MAXIMAL_CONES_GENERATORS__131'); return false;"><b>N_MAXIMAL_CONES_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_MAXIMAL_CONES_GENERATORS__131" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_ORBITS__128" onclick="swap_content('span:group__N_ORBITS__128'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_ORBITS__128" onclick="swap_content('span:group__N_ORBITS__128'); return false;"><b>N_ORBITS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_ORBITS__128" class="foldit">
                                  <div class="descr">
                                    <p> The number of orbits in the domain under the group action</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_ORBIT_REPRESENTATIVES__111" onclick="swap_content('span:group__N_ORBIT_REPRESENTATIVES__111'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_ORBIT_REPRESENTATIVES__111" onclick="swap_content('span:group__N_ORBIT_REPRESENTATIVES__111'); return false;"><b>N_ORBIT_REPRESENTATIVES</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_ORBIT_REPRESENTATIVES__111" class="foldit">
                                  <div class="descr">
                                    <p> the number of representatives of orbits</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__N_RAYS_GENERATORS__110" onclick="swap_content('span:group__N_RAYS_GENERATORS__110'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__N_RAYS_GENERATORS__110" onclick="swap_content('span:group__N_RAYS_GENERATORS__110'); return false;"><b>N_RAYS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__N_RAYS_GENERATORS__110" class="foldit">
                                  <div class="descr">
                                    <p> The number of generators for orbits.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ORBITS__130" onclick="swap_content('span:group__ORBITS__130'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ORBITS__130" onclick="swap_content('span:group__ORBITS__130'); return false;"><b>ORBITS</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Set&lt;Int&gt;&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__ORBITS__130" class="foldit">
                                  <div class="descr">
                                    <p> The orbits of the domain, represented via their indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ORBIT_REPRESENTATIVES__136" onclick="swap_content('span:group__ORBIT_REPRESENTATIVES__136'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ORBIT_REPRESENTATIVES__136" onclick="swap_content('span:group__ORBIT_REPRESENTATIVES__136'); return false;"><b>ORBIT_REPRESENTATIVES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__ORBIT_REPRESENTATIVES__136" class="foldit">
                                  <div class="descr">
                                    <p> A collection of representatives for each orbit, represented via their indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ORBIT_REPRESENTATIVE_LABELS__124" onclick="swap_content('span:group__ORBIT_REPRESENTATIVE_LABELS__124'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ORBIT_REPRESENTATIVE_LABELS__124" onclick="swap_content('span:group__ORBIT_REPRESENTATIVE_LABELS__124'); return false;"><b>ORBIT_REPRESENTATIVE_LABELS</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;String&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__ORBIT_REPRESENTATIVE_LABELS__124" class="foldit">
                                  <div class="descr">
                                    <p> Labels for the orbit representatives</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ORBIT_SIZES__135" onclick="swap_content('span:group__ORBIT_SIZES__135'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ORBIT_SIZES__135" onclick="swap_content('span:group__ORBIT_SIZES__135'); return false;"><b>ORBIT_SIZES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__ORBIT_SIZES__135" class="foldit">
                                  <div class="descr">
                                    <p> The cardinality of each orbit</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__PERMUTATION_TO_ORBIT_ORDER__120" onclick="swap_content('span:group__PERMUTATION_TO_ORBIT_ORDER__120'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__PERMUTATION_TO_ORBIT_ORDER__120" onclick="swap_content('span:group__PERMUTATION_TO_ORBIT_ORDER__120'); return false;"><b>PERMUTATION_TO_ORBIT_ORDER</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__PERMUTATION_TO_ORBIT_ORDER__120" class="foldit">
                                  <div class="descr">
                                    <p> A permutation that orders the domain elements by orbits</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__RAYS_GENERATORS__126" onclick="swap_content('span:group__RAYS_GENERATORS__126'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__RAYS_GENERATORS__126" onclick="swap_content('span:group__RAYS_GENERATORS__126'); return false;"><b>RAYS_GENERATORS</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix</a>
                                <br/>
                                <div style="display: inline" id="span:group__RAYS_GENERATORS__126" class="foldit">
                                  <div class="descr">
                                    <p> A set of generators for rays, stored as the rows of a matrix.
 The list of generators may be redundant and non-canonical.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                        </ul>
                      </div>
                    </div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Group__20" onclick="swap_content('span:group__Group__20'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__Group__20" onclick="swap_content('span:group__Group__20'); return false;">
                  <span class="object">Group</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Group__20" class="foldit">
              <div class="descr">
                <p> Object encoding a finite group.</p>
              </div>
              <div class="level3"/>
              <h4>Properties of Group</h4>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__Symmetry__100" onclick="swap_content('span:group__Symmetry__100'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <div class="category">
                        <h3>
                          <a href="#" class="javalink" id="group__Symmetry__100" onclick="swap_content('span:group__Symmetry__100'); return false;">
                            <span class="category">Symmetry</span>
                          </a>
                        </h3>
                      </div>
                      <div style="display: inline" id="span:group__Symmetry__100" class="foldit">
                        <div class="descr">
                          <p> These properties capture information of the object that is concerned with the action of permutation groups.</p>
                        </div>
                        <ul class="unfoldable">
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__CHARACTER_TABLE__148" onclick="swap_content('span:group__CHARACTER_TABLE__148'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__CHARACTER_TABLE__148" onclick="swap_content('span:group__CHARACTER_TABLE__148'); return false;"><b>CHARACTER_TABLE</b>:
		</a>
                                <a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">common::Matrix&lt;QuadraticExtension&lt;Rational&gt;, NonSymmetric&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__CHARACTER_TABLE__148" class="foldit">
                                  <div class="descr">
                                    <p> The character table.
 NOTE: We do not support complex characters, but for the moment only real ones.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__CONJUGACY_CLASS_SIZES__140" onclick="swap_content('span:group__CONJUGACY_CLASS_SIZES__140'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__CONJUGACY_CLASS_SIZES__140" onclick="swap_content('span:group__CONJUGACY_CLASS_SIZES__140'); return false;"><b>CONJUGACY_CLASS_SIZES</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__CONJUGACY_CLASS_SIZES__140" class="foldit">
                                  <div class="descr">
                                    <p> The sizes of the conjugacy classes</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__FACETS_ACTION__146" onclick="swap_content('span:group__FACETS_ACTION__146'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__FACETS_ACTION__146" onclick="swap_content('span:group__FACETS_ACTION__146'); return false;"><b>FACETS_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__FACETS_ACTION__146" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__FACET_NORMALS_ACTION__143" onclick="swap_content('span:group__FACET_NORMALS_ACTION__143'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__FACET_NORMALS_ACTION__143" onclick="swap_content('span:group__FACET_NORMALS_ACTION__143'); return false;"><b>FACET_NORMALS_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__FACET_NORMALS_ACTION__143" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__HOMOGENEOUS_COORDINATE_ACTION__149" onclick="swap_content('span:group__HOMOGENEOUS_COORDINATE_ACTION__149'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__HOMOGENEOUS_COORDINATE_ACTION__149" onclick="swap_content('span:group__HOMOGENEOUS_COORDINATE_ACTION__149'); return false;"><b>HOMOGENEOUS_COORDINATE_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__HOMOGENEOUS_COORDINATE_ACTION__149" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices, including the '0'-th homogeneous coordinate</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__IMPLICIT_SET_ACTION__152" onclick="swap_content('span:group__IMPLICIT_SET_ACTION__152'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__IMPLICIT_SET_ACTION__152" onclick="swap_content('span:group__IMPLICIT_SET_ACTION__152'); return false;"><b>IMPLICIT_SET_ACTION</b>:
		</a>
                                <a href="#group__ImplicitActionOnSets__18" onclick="unfold('span:group__ImplicitActionOnSets__18');">ImplicitActionOnSets</a>
                                <br/>
                                <div style="display: inline" id="span:group__IMPLICIT_SET_ACTION__152" class="foldit">
                                  <div class="descr">
                                    <p> an action on sets where only one representative for each orbit is stored</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INEQUALITIES_ACTION__151" onclick="swap_content('span:group__INEQUALITIES_ACTION__151'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INEQUALITIES_ACTION__151" onclick="swap_content('span:group__INEQUALITIES_ACTION__151'); return false;"><b>INEQUALITIES_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__INEQUALITIES_ACTION__151" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INPUT_CONES_ACTION__153" onclick="swap_content('span:group__INPUT_CONES_ACTION__153'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INPUT_CONES_ACTION__153" onclick="swap_content('span:group__INPUT_CONES_ACTION__153'); return false;"><b>INPUT_CONES_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__INPUT_CONES_ACTION__153" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__INPUT_RAYS_ACTION__145" onclick="swap_content('span:group__INPUT_RAYS_ACTION__145'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__INPUT_RAYS_ACTION__145" onclick="swap_content('span:group__INPUT_RAYS_ACTION__145'); return false;"><b>INPUT_RAYS_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__INPUT_RAYS_ACTION__145" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__MAXIMAL_CONES_ACTION__150" onclick="swap_content('span:group__MAXIMAL_CONES_ACTION__150'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__MAXIMAL_CONES_ACTION__150" onclick="swap_content('span:group__MAXIMAL_CONES_ACTION__150'); return false;"><b>MAXIMAL_CONES_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt; as Group::MAXIMAL_CONES_ACTION</a>
                                <br/>
                                <div style="display: inline" id="span:group__MAXIMAL_CONES_ACTION__150" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__ORDER__138" onclick="swap_content('span:group__ORDER__138'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__ORDER__138" onclick="swap_content('span:group__ORDER__138'); return false;"><b>ORDER</b>:
		</a>
                                <a href="common.html#common__Integer__322" onclick="unfold('span:common__Integer__322');">common::Integer</a>
                                <br/>
                                <div style="display: inline" id="span:group__ORDER__138" class="foldit">
                                  <div class="descr">
                                    <p> The number of elements in the group</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__PERMUTATION_ACTION__142" onclick="swap_content('span:group__PERMUTATION_ACTION__142'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__PERMUTATION_ACTION__142" onclick="swap_content('span:group__PERMUTATION_ACTION__142'); return false;"><b>PERMUTATION_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__PERMUTATION_ACTION__142" class="foldit">
                                  <div class="descr">
                                    <p> a permutation action on integers</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__RAYS_ACTION__144" onclick="swap_content('span:group__RAYS_ACTION__144'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__RAYS_ACTION__144" onclick="swap_content('span:group__RAYS_ACTION__144'); return false;"><b>RAYS_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__RAYS_ACTION__144" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__REGULAR_REPRESENTATION__147" onclick="swap_content('span:group__REGULAR_REPRESENTATION__147'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__REGULAR_REPRESENTATION__147" onclick="swap_content('span:group__REGULAR_REPRESENTATION__147'); return false;"><b>REGULAR_REPRESENTATION</b>:
		</a>
                                <a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors&lt;Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__REGULAR_REPRESENTATION__147" class="foldit">
                                  <div class="undoc">UNDOCUMENTED</div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__SET_ACTION__139" onclick="swap_content('span:group__SET_ACTION__139'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__SET_ACTION__139" onclick="swap_content('span:group__SET_ACTION__139'); return false;"><b>SET_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Set&lt;Int&gt;, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__SET_ACTION__139" class="foldit">
                                  <div class="descr">
                                    <p> a permutation action on a collection of sets of integers</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__SIMPLEXITY_LOWER_BOUND__154" onclick="swap_content('span:group__SIMPLEXITY_LOWER_BOUND__154'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__SIMPLEXITY_LOWER_BOUND__154" onclick="swap_content('span:group__SIMPLEXITY_LOWER_BOUND__154'); return false;"><b>SIMPLEXITY_LOWER_BOUND</b>:
		</a>
                                <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                                <br/>
                                <div style="display: inline" id="span:group__SIMPLEXITY_LOWER_BOUND__154" class="foldit">
                                  <div class="descr">
                                    <p> The symmetrized version of <a href="#group__SIMPLEXITY_LOWER_BOUND__154" onclick="unfold('span:group__SIMPLEXITY_LOWER_BOUND__154');">SIMPLEXITY_LOWER_BOUND</a>.</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__VECTOR_ACTION__141" onclick="swap_content('span:group__VECTOR_ACTION__141'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__VECTOR_ACTION__141" onclick="swap_content('span:group__VECTOR_ACTION__141'); return false;"><b>VECTOR_ACTION</b>:
		</a>
                                <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Int, Rational&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__VECTOR_ACTION__141" class="foldit">
                                  <div class="descr">
                                    <p> operates on indices</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                        </ul>
                      </div>
                    </div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__ImplicitActionOnSets__18" onclick="swap_content('span:group__ImplicitActionOnSets__18'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__ImplicitActionOnSets__18" onclick="swap_content('span:group__ImplicitActionOnSets__18'); return false;">
                  <span class="object">ImplicitActionOnSets</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__ImplicitActionOnSets__18" class="foldit">
              <div class="descr">
                <p> derived object encoding an action of a permutation group on a collection of sets,
 but where only one representative of each orbit is stored explicitly</p>
              </div>
              <b>derived from: </b>
              <a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction&lt;Bitset, Rational&gt;</a>
              <br/>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__LayeredPermutationAction__17" onclick="swap_content('span:group__LayeredPermutationAction__17'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__LayeredPermutationAction__17" onclick="swap_content('span:group__LayeredPermutationAction__17'); return false;">
                  <span class="object">LayeredPermutationAction</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__LayeredPermutationAction__17" class="foldit">
              <div class="descr">
                <p> object for encoding the separate actions of a group on a collection of sets, induced by the same generators</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__MatrixActionOnVectors__19" onclick="swap_content('span:group__MatrixActionOnVectors__19'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__MatrixActionOnVectors__19" onclick="swap_content('span:group__MatrixActionOnVectors__19'); return false;">
                  <span class="object">MatrixActionOnVectors</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__MatrixActionOnVectors__19" class="foldit">
              <div class="descr">
                <p> derived object for matrix groups</p>
              </div>
              <b>derived from: </b>
              <a href="#group__Action__16" onclick="unfold('span:group__Action__16');">Action&lt;Matrix&lt;Rational, NonSymmetric&gt;, Vector&lt;Rational&gt;, Rational&gt;</a>
              <br/>
              <div class="level3"/>
              <h4>Properties of MatrixActionOnVectors</h4>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__Symmetry__99" onclick="swap_content('span:group__Symmetry__99'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <div class="category">
                        <h3>
                          <a href="#" class="javalink" id="group__Symmetry__99" onclick="swap_content('span:group__Symmetry__99'); return false;">
                            <span class="category">Symmetry</span>
                          </a>
                        </h3>
                      </div>
                      <div style="display: inline" id="span:group__Symmetry__99" class="foldit">
                        <div class="descr">
                          <p> These properties capture information of the object that is concerned with the action of permutation groups.</p>
                        </div>
                        <ul class="unfoldable">
                          <li>
                            <div class="li">
                              <div class="icon" id="icon:group__VECTORS_ORBITS__137" onclick="swap_content('span:group__VECTORS_ORBITS__137'); return false;">
		 	
	</div>
                              <div class="unfoldable">
                                <a href="#" class="javalink" id="group__VECTORS_ORBITS__137" onclick="swap_content('span:group__VECTORS_ORBITS__137'); return false;"><b>VECTORS_ORBITS</b>:
		</a>
                                <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Set&lt;Int&gt;&gt;</a>
                                <br/>
                                <div style="display: inline" id="span:group__VECTORS_ORBITS__137" class="foldit">
                                  <div class="descr">
                                    <p> orbits of vectors under a matrix group</p>
                                  </div>
                                </div>
                              </div>
                            </div>
                          </li>
                        </ul>
                      </div>
                    </div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__PermutationAction__15" onclick="swap_content('span:group__PermutationAction__15'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__PermutationAction__15" onclick="swap_content('span:group__PermutationAction__15'); return false;">
                  <span class="object">PermutationAction</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__PermutationAction__15" class="foldit">
              <div class="descr">
                <p> derived objects for permutation representations</p>
              </div>
              <b>derived from: </b>
              <a href="#group__Action__16" onclick="unfold('span:group__Action__16');">Action&lt;Array&lt;Int&gt;, Int, Rational&gt;</a>
              <br/>
              <div class="level3"/>
              <h4>Properties of PermutationAction</h4>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__BASE__96" onclick="swap_content('span:group__BASE__96'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <a href="#" class="javalink" id="group__BASE__96" onclick="swap_content('span:group__BASE__96'); return false;"><b>BASE</b>:
		</a>
                      <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                      <br/>
                      <div style="display: inline" id="span:group__BASE__96" class="foldit">
                        <div class="descr">
                          <p> A base for <a href="#group__STRONG_GENERATORS__95" onclick="unfold('span:group__STRONG_GENERATORS__95');">STRONG_GENERATORS</a>.</p>
                        </div>
                      </div>
                    </div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__N_STRONG_GENERATORS__97" onclick="swap_content('span:group__N_STRONG_GENERATORS__97'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <a href="#" class="javalink" id="group__N_STRONG_GENERATORS__97" onclick="swap_content('span:group__N_STRONG_GENERATORS__97'); return false;"><b>N_STRONG_GENERATORS</b>:
		</a>
                      <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">common::Int</a>
                      <br/>
                      <div style="display: inline" id="span:group__N_STRONG_GENERATORS__97" class="foldit">
                        <div class="descr">
                          <p> The number of <a href="#group__STRONG_GENERATORS__95" onclick="unfold('span:group__STRONG_GENERATORS__95');">STRONG_GENERATORS</a>.</p>
                        </div>
                      </div>
                    </div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__STRONG_GENERATORS__95" onclick="swap_content('span:group__STRONG_GENERATORS__95'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <a href="#" class="javalink" id="group__STRONG_GENERATORS__95" onclick="swap_content('span:group__STRONG_GENERATORS__95'); return false;"><b>STRONG_GENERATORS</b>:
		</a>
                      <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Array&lt;Int&gt;&gt;</a>
                      <br/>
                      <div style="display: inline" id="span:group__STRONG_GENERATORS__95" class="foldit">
                        <div class="descr">
                          <p> Strong generating set with respect to <a href="#group__BASE__96" onclick="unfold('span:group__BASE__96');">BASE</a>.</p>
                        </div>
                      </div>
                    </div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__TRANSVERSALS__93" onclick="swap_content('span:group__TRANSVERSALS__93'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <a href="#" class="javalink" id="group__TRANSVERSALS__93" onclick="swap_content('span:group__TRANSVERSALS__93'); return false;"><b>TRANSVERSALS</b>:
		</a>
                      <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Array&lt;Int&gt;&gt;</a>
                      <br/>
                      <div style="display: inline" id="span:group__TRANSVERSALS__93" class="foldit">
                        <div class="descr">
                          <p> Transversals along the stabilizer chain. </p>
                        </div>
                      </div>
                    </div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__TRANSVERSAL_SIZES__94" onclick="swap_content('span:group__TRANSVERSAL_SIZES__94'); return false;">
		 	
	</div>
                    <div class="unfoldable">
                      <a href="#" class="javalink" id="group__TRANSVERSAL_SIZES__94" onclick="swap_content('span:group__TRANSVERSAL_SIZES__94'); return false;"><b>TRANSVERSAL_SIZES</b>:
		</a>
                      <a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">common::Array&lt;Int&gt;</a>
                      <br/>
                      <div style="display: inline" id="span:group__TRANSVERSAL_SIZES__94" class="foldit">
                        <div class="descr">
                          <p> The number of group elements per transversal.</p>
                        </div>
                      </div>
                    </div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__PermutationActionOnSets__21" onclick="swap_content('span:group__PermutationActionOnSets__21'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="object">
              <h3>
                <a href="#" class="javalink" id="group__PermutationActionOnSets__21" onclick="swap_content('span:group__PermutationActionOnSets__21'); return false;">
                  <span class="object">PermutationActionOnSets</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__PermutationActionOnSets__21" class="foldit">
              <div class="descr">
                <p> derived object for permuting collections of sets</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
    </ul>
  </div>
  <div class="level2">
    <h2>User Functions</h2>
    <ul class="unfoldable">
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Orbits__12" onclick="swap_content('span:group__Orbits__12'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="category">
              <h3>
                <a href="#" class="javalink" id="group__Orbits__12" onclick="swap_content('span:group__Orbits__12'); return false;">
                  <span class="category">Orbits</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Orbits__12" class="foldit">
              <div class="descr">
                <p> These functions are concerned with orbits in groups.</p>
              </div>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__are_in_same_orbit__31" onclick="swap_content('span:group__are_in_same_orbit__31'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__are_in_same_orbit__31" onclick="swap_content('span:group__are_in_same_orbit__31'); return false;"><b>are_in_same_orbit</b></a>
			(a, v1, v2)  

			
				→ Bool<div style="display: inline" id="span:group__are_in_same_orbit__31" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Checks whether vectors <em class="param">v1</em> and <em class="param">v2</em> are in the same orbit
 with respect to the (coordinate) action of <em class="param">group</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>the permutation group acting on coordinates</div></div></td></tr><tr><td><a href="common.html#common__Vector__306" onclick="unfold('span:common__Vector__306');">Vector</a></td><td class="param">v1</td><td/></tr><tr><td><a href="common.html#common__Vector__306" onclick="unfold('span:common__Vector__306');">Vector</a></td><td class="param">v2</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbit__34" onclick="swap_content('span:group__orbit__34'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbit__34" onclick="swap_content('span:group__orbit__34'); return false;"><b>orbit</b></a>
			&lt;action_type&gt;
		 
			(G, O)  

			
				→ Set&lt;Object&gt;<div style="display: inline" id="span:group__orbit__34" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The orbit of an object <em class="param">O</em> under a group generated by <em class="param">G</em>.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">action_type</td><td><div class="descr"><div>one of: <a href="#group__on_container__7" onclick="unfold('span:group__on_container__7');">on_container</a>, <a href="#group__on_elements__9" onclick="unfold('span:group__on_elements__9');">on_elements</a>, <a href="#group__on_rows__5" onclick="unfold('span:group__on_rows__5');">on_rows</a>, <a href="#group__on_cols__6" onclick="unfold('span:group__on_cols__6');">on_cols</a>, <a href="#group__on_nonhomog_cols__8" onclick="unfold('span:group__on_nonhomog_cols__8');">on_nonhomog_cols</a></div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array</a></td><td class="param">G</td><td><div class="descr"><div>Group generators</div></div></td></tr><tr><td><a href="core.html#core__Core__Object__7" onclick="unfold('span:core__Core__Object__7');">Object</a></td><td class="param">O</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Object&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__79" onclick="swap_content('span:group__overload_1__79'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__79" onclick="swap_content('span:group__overload_1__79'); return false;"><b>orbit</b></a>
			(G, C)  

			
				→ Set&lt;container&gt;<div style="display: inline" id="span:group__overload_1__79" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The orbit of an container <em class="param">C</em> under a group<em class="param">G</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td/></tr><tr><td><a href="#" onclick="unfold('span:');">Any</a></td><td class="param">C</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;container&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_2__77" onclick="swap_content('span:group__overload_2__77'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_2__77" onclick="swap_content('span:group__overload_2__77'); return false;"><b>orbit</b></a>
			&lt;Scalar&gt;
		 
			(G, V)  

			
				→ Set<div style="display: inline" id="span:group__overload_2__77" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The orbit of a vector <em class="param">V</em> under a group generated by <em class="param">G</em>.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Scalar</td><td><div class="descr"><div>S the number type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Matrix&lt;Scalar&gt;&gt;</a></td><td class="param">G</td><td><div class="descr"><div>Generators of the group</div></div></td></tr><tr><td><a href="common.html#common__Vector__306" onclick="unfold('span:common__Vector__306');">Vector&lt;Scalar&gt;</a></td><td class="param">V</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbits_in_orbit_order__32" onclick="swap_content('span:group__orbits_in_orbit_order__32'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbits_in_orbit_order__32" onclick="swap_content('span:group__orbits_in_orbit_order__32'); return false;"><b>orbits_in_orbit_order</b></a>
			(a, M)  

			
				→ List<div style="display: inline" id="span:group__orbits_in_orbit_order__32" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the orbit of the rows of the matrix <em class="param">mat</em>
 under the permutation action on coordinates <em class="param">action</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>an action of a group of coordinate permutations</div></div></td></tr><tr><td><a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">Matrix&lt;Scalar&gt;</a></td><td class="param">M</td><td><div class="descr"><div>some input vectors</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__List__326" onclick="unfold('span:common__List__326');">List</a></td><td><div class="descr"><div>( Matrix generated vectors in orbit order, Array orbits of generated vectors)</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbits_of_action__30" onclick="swap_content('span:group__orbits_of_action__30'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbits_of_action__30" onclick="swap_content('span:group__orbits_of_action__30'); return false;"><b>orbits_of_action</b></a>
			(a)  

			
				→ Array&lt;Set&lt;Int&gt;&gt;<div style="display: inline" id="span:group__orbits_of_action__30" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the orbits of the basic set under <em class="param">a</em>. </p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>a permutation action of a group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Set&lt;Int&gt;&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbits_of_coordinate_action__28" onclick="swap_content('span:group__orbits_of_coordinate_action__28'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbits_of_coordinate_action__28" onclick="swap_content('span:group__orbits_of_coordinate_action__28'); return false;"><b>orbits_of_coordinate_action</b></a>
			(a, M)  

			
				→ Array&lt;Set&lt;Int&gt;&gt;<div style="display: inline" id="span:group__orbits_of_coordinate_action__28" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the orbits of the vectors (homogenized) of the rows of a matrix <em class="param">M</em> by
 permuting the coordinates of the vectors (skipping the homogenizing coordinate).
 The group must act on the set of vectors, and the rows of the matrix must contain the entire orbit.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>an action of a group acting by permuting the coordinates</div></div></td></tr><tr><td><a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">Matrix&lt;Scalar&gt;</a></td><td class="param">M</td><td><div class="descr"><div>a matrix on whose columns the group acts by 
    coordinate permutation</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Set&lt;Int&gt;&gt;</a></td><td><div class="descr"><div>an array of the orbits under the action on the coordinates</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbits_of_induced_action__33" onclick="swap_content('span:group__orbits_of_induced_action__33'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbits_of_induced_action__33" onclick="swap_content('span:group__orbits_of_induced_action__33'); return false;"><b>orbits_of_induced_action</b></a>
			(a, I)  

			
				→ Array&lt;Set&lt;Int&gt;&gt;<div style="display: inline" id="span:group__orbits_of_induced_action__33" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the orbits of a set on which an action is induced.
 The incidences between the domain elements and the elements
 in the set are given by an incidence matrix <em class="param">inc</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>an action of a group</div></div></td></tr><tr><td><a href="common.html#common__IncidenceMatrix__280" onclick="unfold('span:common__IncidenceMatrix__280');">IncidenceMatrix</a></td><td class="param">I</td><td><div class="descr"><div>the incidences between domain elements and elements on which an action is induced</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Set&lt;Int&gt;&gt;</a></td><td><div class="descr"><div>an array of the orbits of the induced action</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbit_permlib__27" onclick="swap_content('span:group__orbit_permlib__27'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbit_permlib__27" onclick="swap_content('span:group__orbit_permlib__27'); return false;"><b>orbit_permlib</b></a>
			(G, S)  

			
				→ Set<div style="display: inline" id="span:group__orbit_permlib__27" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The orbit of a set <em class="param">S</em> under a group <em class="param">G</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td/></tr><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td class="param">S</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__76" onclick="swap_content('span:group__overload_1__76'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__76" onclick="swap_content('span:group__overload_1__76'); return false;"><b>orbit_permlib</b></a>
			(G, S)  

			
				→ Set<div style="display: inline" id="span:group__overload_1__76" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The orbit of a set <em class="param">S</em> of sets under a group <em class="param">G</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td/></tr><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Set&gt;</a></td><td class="param">S</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#" onclick="unfold('span:');">Set</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__orbit_representatives__29" onclick="swap_content('span:group__orbit_representatives__29'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__orbit_representatives__29" onclick="swap_content('span:group__orbit_representatives__29'); return false;"><b>orbit_representatives</b></a>
			(G)  

			
				→ Array&lt;Int&gt;<div style="display: inline" id="span:group__orbit_representatives__29" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The indices of one representative for each orbit under the group generated by <em class="param">G</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;GeneratorType&gt;</a></td><td class="param">G</td><td><div class="descr"><div>Group generators</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Producing_a_group__13" onclick="swap_content('span:group__Producing_a_group__13'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="category">
              <h3>
                <a href="#" class="javalink" id="group__Producing_a_group__13" onclick="swap_content('span:group__Producing_a_group__13'); return false;">
                  <span class="category">Producing a group</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Producing_a_group__13" class="foldit">
              <div class="descr">
                <p> With these clients you can produce objects of type <a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a> -- groups from certain parameterized families, as stabilizers of sets in other groups or from different kinds of cycle notations.</p>
              </div>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__alternating_group__35" onclick="swap_content('span:group__alternating_group__35'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__alternating_group__35" onclick="swap_content('span:group__alternating_group__35'); return false;"><b>alternating_group</b></a>
			(d)  

			
				→ Group<div style="display: inline" id="span:group__alternating_group__35" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs an <em class="u">alternating group</em> of given degree <em class="param">d</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">d</td><td><div class="descr"><div>degree of the alternating group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__cube_group__41" onclick="swap_content('span:group__cube_group__41'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__cube_group__41" onclick="swap_content('span:group__cube_group__41'); return false;"><b>cube_group</b></a>
			(d)  

			
				→ Group<div style="display: inline" id="span:group__cube_group__41" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs the symmetry group of a d-cube, acting on vertices, for 3 &lt;= d &lt;= 6 (for the moment),
 along with the corresponding character table and conjugacy class representatives.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">d</td><td><div class="descr"><div>the dimension of the cube</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__cyclic_group__42" onclick="swap_content('span:group__cyclic_group__42'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__cyclic_group__42" onclick="swap_content('span:group__cyclic_group__42'); return false;"><b>cyclic_group</b></a>
			(d)  

			
				→ Group<div style="display: inline" id="span:group__cyclic_group__42" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a <em class="u">cyclic group</em> of given degree <em class="param">d</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">d</td><td><div class="descr"><div>degree of the cyclic group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__dihedral_group__40" onclick="swap_content('span:group__dihedral_group__40'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__dihedral_group__40" onclick="swap_content('span:group__dihedral_group__40'); return false;"><b>dihedral_group</b></a>
			(o)  

			
				→ Group<div style="display: inline" id="span:group__dihedral_group__40" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a <em class="u">dihedral group</em> of a given order <em class="param">o</em>.
 If the order is 2, 4, 6, 8, 10, 12, 16, 20 or 24, the character table is exact,
 otherwise some entries are mutilated rational approximations of algebraic numbers.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">o</td><td><div class="descr"><div>order of the dihedral group that acts on a regular <em class="param">(o/2)</em>-gon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__group_from_cyclic_notation0__36" onclick="swap_content('span:group__group_from_cyclic_notation0__36'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__group_from_cyclic_notation0__36" onclick="swap_content('span:group__group_from_cyclic_notation0__36'); return false;"><b>group_from_cyclic_notation0</b></a>
			(generators)  

			
				→ Group<div style="display: inline" id="span:group__group_from_cyclic_notation0__36" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a group from a string with generators in cyclic notation.
 All numbers in the string are 0-based.
 Example: "(0,2)(1,3)"</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">generators</td><td><div class="descr"><div>the group generators in cyclic notation</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__group_from_cyclic_notation1__38" onclick="swap_content('span:group__group_from_cyclic_notation1__38'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__group_from_cyclic_notation1__38" onclick="swap_content('span:group__group_from_cyclic_notation1__38'); return false;"><b>group_from_cyclic_notation1</b></a>
			(generators)  

			
				→ Group<div style="display: inline" id="span:group__group_from_cyclic_notation1__38" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a group from a string with generators in cyclic notation.
 All numbers in the string are 1-based.
 Example: "(1,3)(2,4)"</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">generators</td><td><div class="descr"><div>the group generators in cyclic notation</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__group_from_permlib_cyclic_notation__43" onclick="swap_content('span:group__group_from_permlib_cyclic_notation__43'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__group_from_permlib_cyclic_notation__43" onclick="swap_content('span:group__group_from_permlib_cyclic_notation__43'); return false;"><b>group_from_permlib_cyclic_notation</b></a>
			(gens, degree)  

			
				→ Group<div style="display: inline" id="span:group__group_from_permlib_cyclic_notation__43" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a Group from generators given in permlib cyclic notation,
 i.e., indices separated by whitespace, generators separated by commas.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;String&gt;</a></td><td class="param">gens</td><td><div class="descr"><div>generators of the permutation group in permlib cyclic notation</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">degree</td><td><div class="descr"><div>the degree of the permutation group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td><div class="descr"><div>the group generated by <em class="param">gens</em></div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__stabilizer_of_set__39" onclick="swap_content('span:group__stabilizer_of_set__39'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__stabilizer_of_set__39" onclick="swap_content('span:group__stabilizer_of_set__39'); return false;"><b>stabilizer_of_set</b></a>
			(a, S)  

			
				→ Group<div style="display: inline" id="span:group__stabilizer_of_set__39" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the subgroup of <em class="param">group</em> which stabilizes
 the given set of indices <em class="param">set</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>the action of a permutation group</div></div></td></tr><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td class="param">S</td><td><div class="descr"><div>the set to be stabilized</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td><div class="descr"><div>the stabilizer of <em class="param">S</em> w.r.t. <em class="param">a</em></div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__stabilizer_of_vector__44" onclick="swap_content('span:group__stabilizer_of_vector__44'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__stabilizer_of_vector__44" onclick="swap_content('span:group__stabilizer_of_vector__44'); return false;"><b>stabilizer_of_vector</b></a>
			(a, v)  

			
				→ Group<div style="display: inline" id="span:group__stabilizer_of_vector__44" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the subgroup of <em class="param">G</em> which stabilizes the given vector <em class="param">v</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>the action of a permutation group</div></div></td></tr><tr><td><a href="common.html#common__Vector__306" onclick="unfold('span:common__Vector__306');">Vector</a></td><td class="param">v</td><td><div class="descr"><div>the vector to be stabilized</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td><div class="descr"><div>the stabilizer of <em class="param">v</em> w.r.t. <em class="param">a</em></div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__symmetric_group__37" onclick="swap_content('span:group__symmetric_group__37'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__symmetric_group__37" onclick="swap_content('span:group__symmetric_group__37'); return false;"><b>symmetric_group</b></a>
			(d)  

			
				→ Group<div style="display: inline" id="span:group__symmetric_group__37" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Constructs a <em class="u">symmetric group</em> of given degree <em class="param">d</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">d</td><td><div class="descr"><div>degree of the symmetric group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Symmetry__14" onclick="swap_content('span:group__Symmetry__14'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="category">
              <h3>
                <a href="#" class="javalink" id="group__Symmetry__14" onclick="swap_content('span:group__Symmetry__14'); return false;">
                  <span class="category">Symmetry</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Symmetry__14" class="foldit">
              <div class="descr">
                <p> These functions capture information of the object that is concerned with the action of permutation groups.</p>
              </div>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__all_group_elements__66" onclick="swap_content('span:group__all_group_elements__66'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__all_group_elements__66" onclick="swap_content('span:group__all_group_elements__66'); return false;"><b>all_group_elements</b></a>
			&lt;Scalar&gt;
		 
			(action)  

			
				→ Set&lt;Matrix&lt;Scalar&gt;&gt;<div style="display: inline" id="span:group__all_group_elements__66" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Compute all elements of a given group, expressed as a matrix group action.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Scalar</td><td><div class="descr"><div>S the underlying number type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors&lt;Scalar&gt;</a></td><td class="param">action</td><td><div class="descr"><div>the action of a permutation group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Matrix&lt;Scalar&gt;&gt;</a></td><td><div class="descr"><div>G a set containing all group elements</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">To generate all elements of the regular representation of S_3, type<code>&gt; print all_group_elements(symmetric_group(3)-&gt;REGULAR_REPRESENTATION);</code><code> &lt;0 0 1</code><code> 0 1 0</code><code> 1 0 0</code><code> &gt;</code><code> &lt;0 0 1</code><code> 1 0 0</code><code> 0 1 0</code><code> &gt;</code><code> &lt;0 1 0</code><code> 0 0 1</code><code> 1 0 0</code><code> &gt;</code><code> &lt;0 1 0</code><code> 1 0 0</code><code> 0 0 1</code><code> &gt;</code><code> &lt;1 0 0</code><code> 0 0 1</code><code> 0 1 0</code><code> &gt;</code><code> &lt;1 0 0</code><code> 0 1 0</code><code> 0 0 1</code><code> &gt;</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__col_to_row_action__56" onclick="swap_content('span:group__col_to_row_action__56'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__col_to_row_action__56" onclick="swap_content('span:group__col_to_row_action__56'); return false;"><b>col_to_row_action</b></a>
			(M, of)  

			
				→ Array<div style="display: inline" id="span:group__col_to_row_action__56" class="foldit"><br/><div class="descr_func"><div class="descr"><p> If the action of some permutations on the entries of the rows 
 maps each row of a matrix to another row we obtain an induced action
 on the set of rows of the matrix.
 Considering the rows as points this corresponds to the action on the
 points induced by the action of some permutations on the coordinates.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">Matrix</a></td><td class="param">M</td><td/></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array</a></td><td class="param">of</td><td><div class="descr"><div>permutations</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array</a></td><td><div class="descr"><div>of permutations</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__conjugacy_class__49" onclick="swap_content('span:group__conjugacy_class__49'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__conjugacy_class__49" onclick="swap_content('span:group__conjugacy_class__49'); return false;"><b>conjugacy_class</b></a>
			&lt;Element&gt;
		 
			(action, e)  

			
				→ Set&lt;Element&gt;<div style="display: inline" id="span:group__conjugacy_class__49" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Compute the conjugacy class of a group element under a given action</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Element</td><td><div class="descr"><div>E the underlying element type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Action__16" onclick="unfold('span:group__Action__16');">Action</a></td><td class="param">action</td><td><div class="descr"><div>the action of the group</div></div></td></tr><tr><td><a href="#" onclick="unfold('span:');">Element</a></td><td class="param">e</td><td><div class="descr"><div>the element to be acted upon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Element&gt;</a></td><td><div class="descr"><div>S a set containing the conjugacy class of the element</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__84" onclick="swap_content('span:group__overload_1__84'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__84" onclick="swap_content('span:group__overload_1__84'); return false;"><b>conjugacy_class</b></a>
			&lt;Scalar&gt;
		 
			(action, e)  

			
				→ Set&lt;Matrix&lt;Element&gt;&gt;<div style="display: inline" id="span:group__overload_1__84" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Compute the conjugacy class of a group element under a given action</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Scalar</td><td><div class="descr"><div>E the underlying number type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors&lt;Scalar&gt;</a></td><td class="param">action</td><td><div class="descr"><div>the action of the group</div></div></td></tr><tr><td><a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">Matrix&lt;Scalar&gt;</a></td><td class="param">e</td><td><div class="descr"><div>the element to be acted upon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Matrix&lt;Element&gt;&gt;</a></td><td><div class="descr"><div>S a set containing the conjugacy class of the element</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__group_left_multiplication_table__63" onclick="swap_content('span:group__group_left_multiplication_table__63'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__group_left_multiplication_table__63" onclick="swap_content('span:group__group_left_multiplication_table__63'); return false;"><b>group_left_multiplication_table</b></a>
			(G)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__group_left_multiplication_table__63" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the left multiplication table of a group action, in which GMT[g][h] = hg</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td/></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">action</td><td><div class="descr"><div>which action to take for the calculation; default PERMUTATION_ACTION</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td><div class="descr"><div>GMT the multiplication table, where the elements of <em class="param">G</em> are
 ordered by conjugacy classes (if available), else in generated order</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__group_right_multiplication_table__67" onclick="swap_content('span:group__group_right_multiplication_table__67'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__group_right_multiplication_table__67" onclick="swap_content('span:group__group_right_multiplication_table__67'); return false;"><b>group_right_multiplication_table</b></a>
			(G)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__group_right_multiplication_table__67" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the right multiplication table of a group action, in which GMT[g][h] = gh</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td/></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">action</td><td><div class="descr"><div>which action to take for the calculation; default PERMUTATION_ACTION</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td><div class="descr"><div>GMT the multiplication table, where the elements of <em class="param">G</em> are
 ordered by conjugacy classes (if available), else in generated order</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__implicit_character__58" onclick="swap_content('span:group__implicit_character__58'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__implicit_character__58" onclick="swap_content('span:group__implicit_character__58'); return false;"><b>implicit_character</b></a>
			(A)  

			
				→ Array&lt;Int&gt;<div style="display: inline" id="span:group__implicit_character__58" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate character of an implicit action</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__ImplicitActionOnSets__18" onclick="unfold('span:group__ImplicitActionOnSets__18');">ImplicitActionOnSets</a></td><td class="param">A</td><td><div class="descr"><div>the given action</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__induced_action__70" onclick="swap_content('span:group__induced_action__70'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__induced_action__70" onclick="swap_content('span:group__induced_action__70'); return false;"><b>induced_action</b></a>
			(a, domain)  

			
				→ PermutationActionOnSets<div style="display: inline" id="span:group__induced_action__70" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Given a permutation action <em class="param">a</em> on some indices and an ordered list <em class="param">domain</em> of sets containing these indices,
 we ask for the permutation action induced by <em class="param">a</em> on this list of sets.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>a permutation action that acts on some indices</div></div></td></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Set&lt;Int&gt;&gt;</a></td><td class="param">domain</td><td><div class="descr"><div>a list of sets of indices that <em class="param">a</em> should act on</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td/></tr></table></div><br/><div class="examples"><b>Examples:</b><ul><li><div class="descr">Consider the symmetry group of the 3-cube acting on vertices, and induce from it the action on the facets:<code>&gt; $a = cube_group(3)-&gt;PERMUTATION_ACTION;</code><code>&gt; $f = new Array&lt;Set&gt;([[0,2,4,6],[1,3,5,7],[0,1,4,5],[2,3,6,7],[0,1,2,3],[4,5,6,7]]);</code><code>&gt; print $a-&gt;GENERATORS;</code><code> 1 0 3 2 5 4 7 6</code><code> 0 2 1 3 4 6 5 7</code><code> 0 1 4 5 2 3 6 7</code><code>&gt; print induced_action($a,$f)-&gt;GENERATORS;</code><code> 1 0 2 3 4 5</code><code> 2 3 0 1 4 5</code><code> 0 1 4 5 2 3</code></div></li><li><div class="descr">To see what the permutation [0,2,1] induces on the array [{0,1},{0,2}], do the following:<code>&gt; $a = new Array&lt;Set&lt;Int&gt;&gt;(2);</code><code>&gt; $a-&gt;[0] = new Set&lt;Int&gt;(0,1);</code><code>&gt; $a-&gt;[1] = new Set&lt;Int&gt;(0,2);</code><code>&gt; $p = new PermutationAction(GENERATORS=&gt;[[0,2,1]]);</code><code>&gt; print induced_action($p,$a)-&gt;properties;</code><code> type: PermutationActionOnSets</code><code> </code><code> GENERATORS</code><code> 1 0</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__induced_permutations__60" onclick="swap_content('span:group__induced_permutations__60'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__induced_permutations__60" onclick="swap_content('span:group__induced_permutations__60'); return false;"><b>induced_permutations</b></a>
			(gens, M)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__induced_permutations__60" class="foldit"><br/><div class="descr_func"><div class="descr"><p> gives the permutations that are induced on the rows of a matrix <em class="param">M</em>
 by the action of <em class="param">gens</em> on the columns of <em class="param">M</em></p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td class="param">gens</td><td><div class="descr"><div>a list of permutations</div></div></td></tr><tr><td><a href="common.html#common__Matrix__300" onclick="unfold('span:common__Matrix__300');">Matrix</a></td><td class="param">M</td><td><div class="descr"><div>the matrix acted upon</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">homogeneous_action</td><td><div class="descr"><div>should the generators also act on the homogeneous column? Default False</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__89" onclick="swap_content('span:group__overload_1__89'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__89" onclick="swap_content('span:group__overload_1__89'); return false;"><b>induced_permutations</b></a>
			(gens, M)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__overload_1__89" class="foldit"><br/><div class="descr_func"><div class="descr"><p> gives the permutations that are induced on the rows of a matrix <em class="param">M</em>
 by the action of <em class="param">gens</em> on the columns of <em class="param">M</em></p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Matrix&lt;Scalar&gt;&gt;</a></td><td class="param">gens</td><td><div class="descr"><div>a list of matrices that act as generators</div></div></td></tr><tr><td><a href="#" onclick="unfold('span:');">Matrix</a></td><td class="param">M</td><td><div class="descr"><div>the matrix acted upon</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">homogeneous_action</td><td><div class="descr"><div>should the generators also act on the homogeneous column? Default False</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_2__92" onclick="swap_content('span:group__overload_2__92'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_2__92" onclick="swap_content('span:group__overload_2__92'); return false;"><b>induced_permutations</b></a>
			(gens, S)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__overload_2__92" class="foldit"><br/><div class="descr_func"><div class="descr"><p> gives the permutations that are induced on an ordered collection <em class="param">S</em>
 by the action of <em class="param">gens</em> on the elements of <em class="param">S</em></p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td class="param">gens</td><td/></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;DomainType&gt;</a></td><td class="param">S</td><td><div class="descr"><div>the collection acted upon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_3__90" onclick="swap_content('span:group__overload_3__90'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_3__90" onclick="swap_content('span:group__overload_3__90'); return false;"><b>induced_permutations</b></a>
			(a, M)  

			
				→ Array&lt;Array&lt;Int&gt;&gt;<div style="display: inline" id="span:group__overload_3__90" class="foldit"><br/><div class="descr_func"><div class="descr"><p> gives the permutations that are induced on the rows of an incidence matrix <em class="param">M</em>
 by the action of <em class="param">gens</em> on the columns of <em class="param">M</em></p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td class="param">a</td><td><div class="descr"><div>the permutation action</div></div></td></tr><tr><td><a href="common.html#common__IncidenceMatrix__280" onclick="unfold('span:common__IncidenceMatrix__280');">IncidenceMatrix</a></td><td class="param">M</td><td><div class="descr"><div>the matrix acted upon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__induced_rep__51" onclick="swap_content('span:group__induced_rep__51'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__induced_rep__51" onclick="swap_content('span:group__induced_rep__51'); return false;"><b>induced_rep</b></a>
			(C, A, g)  

			
				→ SparseMatrix<div style="display: inline" id="span:group__induced_rep__51" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the representation of a group element</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="polytope.html#polytope__Cone__21" onclick="unfold('span:polytope__Cone__21');">polytope::Cone</a></td><td class="param">C</td><td><div class="descr"><div>the cone or polytope containing the sets acted upon</div></div></td></tr><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">A</td><td><div class="descr"><div>the action in question</div></div></td></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td class="param">g</td><td><div class="descr"><div>the group element, acting on vertices</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__induce_implicit_action__54" onclick="swap_content('span:group__induce_implicit_action__54'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__induce_implicit_action__54" onclick="swap_content('span:group__induce_implicit_action__54'); return false;"><b>induce_implicit_action</b></a>
			(original_action, property)  

			
				→ ImplicitActionOnSets<div style="display: inline" id="span:group__induce_implicit_action__54" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Construct an implicit action of the action induced on a collection of sets. Only a set of
 orbit representatives is stored, not the full induced action.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">original_action</td><td><div class="descr"><div>the action of the group on indices</div></div></td></tr><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">property</td><td><div class="descr"><div>the name of a property that describes an ordered list of sets on which the group should act</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__ImplicitActionOnSets__18" onclick="unfold('span:group__ImplicitActionOnSets__18');">ImplicitActionOnSets</a></td><td><div class="descr"><div>the action of the group on the given property, such that only representatives are stored</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">To construct the implicit action of the symmetry group of a cube on its maximal simplices, type:<code>&gt; $c=cube(3, group=&gt;1, character_table=&gt;0);</code><code>&gt; group::induce_implicit_action($c, $c-&gt;GROUP-&gt;VERTICES_ACTION, $c-&gt;GROUP-&gt;REPRESENTATIVE_MAX_INTERIOR_SIMPLICES, "MAX_INTERIOR_SIMPLICES")-&gt;properties();</code><code> name: induced_implicit_action_of_ray_action_on_MAX_INTERIOR_SIMPLICES</code><code> type: ImplicitActionOnSets</code><code> description: induced from ray_action on MAX_INTERIOR_SIMPLICES</code><code> </code><code> GENERATORS</code><code> 1 0 3 2 5 4 7 6</code><code> 0 2 1 3 4 6 5 7</code><code> 0 1 4 5 2 3 6 7</code><code> </code><code> </code><code> DOMAIN_NAME</code><code> MAX_INTERIOR_SIMPLICES</code><code> </code><code> EXPLICIT_ORBIT_REPRESENTATIVES</code><code> {0 1 2 4}</code><code> {0 1 2 5}</code><code> {0 1 2 7}</code><code> {0 3 5 6}</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__induce_set_action__55" onclick="swap_content('span:group__induce_set_action__55'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__induce_set_action__55" onclick="swap_content('span:group__induce_set_action__55'); return false;"><b>induce_set_action</b></a>
			(c, a, domain)  

			
				→ PermutationActionOnSets<div style="display: inline" id="span:group__induce_set_action__55" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Construct the induced action of a permutation action on a property that is an ordered collection of sets,
 such as MAX_INTERIOR_SIMPLICES</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="polytope.html#polytope__Cone__21" onclick="unfold('span:polytope__Cone__21');">polytope::Cone</a></td><td class="param">c</td><td><div class="descr"><div>the cone or polytope</div></div></td></tr><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>a permutation action on, for example, the vertex indices</div></div></td></tr><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">domain</td><td><div class="descr"><div>the property the induced action should act upon</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td/></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr"><code>&gt; $c=cube(3, group=&gt;1, character_table=&gt;0);</code><code>&gt; group::induce_set_action($c, $c-&gt;GROUP-&gt;VERTICES_ACTION, "MAX_INTERIOR_SIMPLICES")-&gt;properties();</code><code> name: induced_set_action_of_ray_action_on_MAX_INTERIOR_SIMPLICES</code><code> type: PermutationActionOnSets</code><code> description: induced from ray_action on MAX_INTERIOR_SIMPLICES</code><code> </code><code> GENERATORS</code><code> 5 4 7 6 1 0 3 2 11 10 9 8 30 29 32 31 38 40 39 41 33 36 35 34 37 43 42 45 44 13 12 15 14 20 23 22 21 24 16 18 17 19 26 25 28 27 49 48 47 46 55 54 57 56 51 50 53 52</code><code> 0 2 1 3 12 14 13 15 16 17 18 19 4 6 5 7 8 9 10 11 21 20 22 24 23 25 27 26 28 29 31 30 32 34 33 35 37 36 46 47 48 49 50 52 51 53 38 39 40 41 42 44 43 45 54 56 55 57</code><code> 0 4 8 9 1 5 10 11 2 3 6 7 16 20 25 26 12 17 21 27 13 18 22 23 28 14 15 19 24 33 38 42 43 29 34 35 39 44 30 36 40 45 31 32 37 41 50 51 54 55 46 47 52 56 48 49 53 57</code><code> </code><code> </code><code> DOMAIN_NAME</code><code> MAX_INTERIOR_SIMPLICES</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__invariant_polynomials__64" onclick="swap_content('span:group__invariant_polynomials__64'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__invariant_polynomials__64" onclick="swap_content('span:group__invariant_polynomials__64'); return false;"><b>invariant_polynomials</b></a>
			(a, d)  

			<div style="display: inline" id="span:group__invariant_polynomials__64" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Given a matrix action <em class="param">a</em> of a group <em class="param">G</em> on some <em class="param">n</em>-dimensional vector space and a total degree <em class="param">d</em>,
 calculate the <em class="param">G</em>-invariant polynomials of total degree 0 &lt; <em class="param">deg</em> ≤ <em class="param">d</em> in <em class="param">n</em> variables.
 This is done by calculating the <em class="param">a</em>-orbit of all monomials of total degree at most <em class="param">d</em>.
 By a theorem of Noether, for <em class="param">d</em> = the order of <em class="param">G</em> the output is guaranteed to generate the entire ring of <em class="param">G</em>-invariant polynomials.
 No effort is made to calculate a basis of the ideal generated by these invariants. </p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors</a></td><td class="param">a</td><td><div class="descr"><div>the matrix action</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">d</td><td><div class="descr"><div>the maximal degree of the sought invariants</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">action_is_affine</td><td><div class="descr"><div>is the action <em class="param">a</em> affine, ie., ignore the first row and column of the generating matrices? Default yes</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">To calculate the invariants of degree at most six of the matrix action of the symmetry group of the 3-cube, type<code>&gt; $c = cube(3, group=&gt;1);</code><code>&gt; print join "\n", @{group::invariant_polynomials($c-&gt;GROUP-&gt;MATRIX_ACTION, 6)};</code><code> x_0^2 + x_1^2 + x_2^2</code><code> x_0^2*x_1^2 + x_0^2*x_2^2 + x_1^2*x_2^2</code><code> x_0^2*x_1^2*x_2^2</code><code> x_0^4 + x_1^4 + x_2^4</code><code> x_0^4*x_1^2 + x_0^4*x_2^2 + x_0^2*x_1^4 + x_0^2*x_2^4 + x_1^4*x_2^2 + x_1^2*x_2^4</code><code> x_0^6 + x_1^6 + x_2^6</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__irreducible_decomposition__52" onclick="swap_content('span:group__irreducible_decomposition__52'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__irreducible_decomposition__52" onclick="swap_content('span:group__irreducible_decomposition__52'); return false;"><b>irreducible_decomposition</b></a>
			(character, G)  

			
				→ Array&lt;Int&gt;<div style="display: inline" id="span:group__irreducible_decomposition__52" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the decomposition into irreducible components of a given representation</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array</a></td><td class="param">character</td><td><div class="descr"><div>the character of the given representation</div></div></td></tr><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the given group; it needs to know its CHARACTER_TABLE and CONJUGACY_CLASS_SIZES.</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td/></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">Remember that in polymake, we use the terms <em class="param">action</em> and <em class="param">representation</em> interchangeably.
 To calculate the irreducible decomposition of the vertex action of the symmetry group of the 3-cube, type<code>&gt; $g = cube_group(3); $a = $g-&gt;PERMUTATION_ACTION;</code><code>&gt; print irreducible_decomposition($a-&gt;CHARACTER, $g);</code><code> 1 0 0 1 0 0 0 0 1 1</code> Thus, the action of the symmetry group on the vertices decomposes into one copy of each of the
 irreducible representations corresponding to the rows 0,3,8,9 of the character table:<code>&gt; print $g-&gt;CHARACTER_TABLE-&gt;minor([0,3,8,9],All);</code><code> 1 1 1 1 1 1 1 1 1 1</code><code> 1 1 1 -1 -1 -1 -1 1 1 -1</code><code> 3 1 0 -1 1 -1 0 -1 -1 3</code><code> 3 1 0 1 -1 1 0 -1 -1 -3</code> The first entries of these rows say that <em class="param">a</em> decomposes into two 1-dimensional irreps and two 3-dimensional ones.
 This correctly brings the dimension of the representation <em class="param">a</em> to 8, the number of vertices of the 3-cube.</div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__isotypic_basis__45" onclick="swap_content('span:group__isotypic_basis__45'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__isotypic_basis__45" onclick="swap_content('span:group__isotypic_basis__45'); return false;"><b>isotypic_basis</b></a>
			(G, A, i)  

			
				→ SparseMatrix<div style="display: inline" id="span:group__isotypic_basis__45" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate a basis of the isotypic component given by the i-th irrep</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the acting group, which needs to know its CHARACTER_TABLE</div></div></td></tr><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">A</td><td><div class="descr"><div>the representation in question, which needs to know its corresponding CONJUGACY_CLASSES</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the sought irrep</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">permute_to_orbit_order</td><td><div class="descr"><div>Should the rows and columns be ordered by orbits? Default 1</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td><div class="descr"><div>a matrix whose rows form a basis of the i-th irrep</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">Consider the action of the symmetry group of the 3-cube on the set of facets:<code>&gt; $g = cube_group(3);</code><code>&gt; $f = new Array&lt;Set&gt;([[0,2,4,6],[1,3,5,7],[0,1,4,5],[2,3,6,7],[0,1,2,3],[4,5,6,7]]);</code><code>&gt; $a = induced_action($g-&gt;PERMUTATION_ACTION, $f);</code><code>&gt; print irreducible_decomposition($a-&gt;CHARACTER, $g)</code><code> 1 0 0 0 0 1 0 0 0 1</code> Now we can calculate a basis of the 5th irrep:<code>&gt; print isotypic_basis($g, $a, 5);</code><code> -1/6 -1/6 1/3 1/3 -1/6 -1/6</code><code> 1/3 1/3 -1/6 -1/6 -1/6 -1/6</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__80" onclick="swap_content('span:group__overload_1__80'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__80" onclick="swap_content('span:group__overload_1__80'); return false;"><b>isotypic_basis</b></a>
			(G, A, i)  

			
				→ SparseMatrix<div style="display: inline" id="span:group__overload_1__80" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate a basis of the isotypic component given by the i-th irrep</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the acting group, which needs to know its CHARACTER_TABLE</div></div></td></tr><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">A</td><td><div class="descr"><div>the action in question, which needs to know its corresponding CONJUGACY_CLASSES</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the sought irrep</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">permute_to_orbit_order</td><td><div class="descr"><div>Should the rows and columns be ordered by orbits? Default 1</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td><div class="descr"><div>a matrix whose rows form a basis of the i-th irrep</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">Consider the action of the symmetry group of the 3-cube on its vertices.
 We first calculate its decomposition into irreducible representations via<code>&gt; $g = cube_group(3); $a = $g-&gt;PERMUTATION_ACTION;</code><code>&gt; print irreducible_decomposition($a-&gt;CHARACTER, $g);</code><code> 1 0 0 1 0 0 0 0 1 1</code> We now calculate a basis of the 3rd irrep:<code>&gt; print isotypic_basis($g,$a,3);</code><code> 1/8 -1/8 -1/8 1/8 -1/8 1/8 1/8 -1/8</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_2__82" onclick="swap_content('span:group__overload_2__82'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_2__82" onclick="swap_content('span:group__overload_2__82'); return false;"><b>isotypic_basis</b></a>
			&lt;Scalar&gt;
		 
			(G, A, i)  

			
				→ SparseMatrix<div style="display: inline" id="span:group__overload_2__82" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate a basis of the isotypic component given by the i-th irrep</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Scalar</td><td><div class="descr"><div>S the underlying number type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the acting group, which needs to know its CHARACTER_TABLE</div></div></td></tr><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors&lt;Scalar&gt;</a></td><td class="param">A</td><td><div class="descr"><div>the matrix action in question, which needs to know its corresponding CONJUGACY_CLASSES</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the sought irrep</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td><div class="descr"><div>a matrix whose rows form a basis of the i-th irrep
 &gt; $s = symmetric_group(3); $a = $s-&gt;REGULAR_REPRESENTATION;
 &gt; print irreducible_decomposition($a-&gt;CHARACTER, $s);
 | 0 1 1
 We now calculate a basis of the 1st irrep:
 &gt; print isotypic_basis($s, $a, 1);
 | 2/3 -1/3 -1/3
 | -1/3 2/3 -1/3
 This is consistent with the information collected in the character table:
 &gt; print $g-&gt;CHARACTER_TABLE-&gt;row(1);
 | 2 0 1
 In effect, the first entry in this rows says that the dimension of this irrep is 2.</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__isotypic_configuration__65" onclick="swap_content('span:group__isotypic_configuration__65'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__isotypic_configuration__65" onclick="swap_content('span:group__isotypic_configuration__65'); return false;"><b>isotypic_configuration</b></a>
			(g, i)  

			
				→ polytope::VectorConfiguration&lt;QuadraticExtension&gt;<div style="display: inline" id="span:group__isotypic_configuration__65" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Given a group <em class="param">g</em>, a permutation action <em class="param">a</em> on some indices and an index <em class="param">i</em>,
 regard <em class="param">a</em> as acting on the unit basis vectors of the ambient space, 
 and return the projections of the unit basis vectors to the <em class="param">i</em>-th isotypic component <em class="param">C_i</em>
 expressed in a basis of <em class="param">C_i</em>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">g</td><td><div class="descr"><div>a group with a permutation action that acts on some indices</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the desired isotypic component</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="#group__Action__16" onclick="unfold('span:group__Action__16');">Action</a></td><td class="param">a</td><td><div class="descr"><div>the action by which <em class="param">g</em> acts. By default, this is the PERMUTATION_ACTION.</div></div></td></tr><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">affine</td><td><div class="descr"><div>prepend a column of ones to the vectors? Default 0</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="polytope.html#polytope__VectorConfiguration__99" onclick="unfold('span:polytope__VectorConfiguration__99');">polytope::VectorConfiguration&lt;QuadraticExtension&gt;</a></td><td/></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">Consider the symmetry group of the 3-cube acting on vertices, and calculate the vector configuration
 corresponding to the isotypic component number 8, which has dimension 3 and multiplicity 1:<code>&gt; $g = group::cube_group(3);</code><code>&gt; print group::isotypic_configuration($g,8)-&gt;VECTORS;</code><code> 0 0 1</code><code> 0 1 0</code><code> 1 0 0</code><code> -1 -1 -1</code><code> -1 -1 -1</code><code> 1 0 0</code><code> 0 1 0</code><code> 0 0 1</code> To get the configuration as POINTS, ask for affine=&gt;1: <code>&gt; print group::isotypic_configuration($g,8,affine=&gt;1)-&gt;POINTS;</code><code> 1 0 0 1</code><code> 1 0 1 0</code><code> 1 1 0 0</code><code> 1 -1 -1 -1</code><code> 1 -1 -1 -1</code><code> 1 1 0 0</code><code> 1 0 1 0</code><code> 1 0 0 1</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__isotypic_projector__50" onclick="swap_content('span:group__isotypic_projector__50'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__isotypic_projector__50" onclick="swap_content('span:group__isotypic_projector__50'); return false;"><b>isotypic_projector</b></a>
			(G, A, i)  

			
				→ SparseMatrix&lt;QuadraticExtension&gt;<div style="display: inline" id="span:group__isotypic_projector__50" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the projection map into the isotypic component given by the i-th irrep.
 The map is given by a block matrix, the rows and columns of which are indexed
 by the domain elements; by default, these are ordered by orbits.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the acting group</div></div></td></tr><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">A</td><td><div class="descr"><div>the action in question</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the sought irrep</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">permute_to_orbit_order</td><td><div class="descr"><div>Should the rows and columns be ordered by orbits? Default 1</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix&lt;QuadraticExtension&gt;</a></td><td><div class="descr"><div>pi the matrix of the projection, the rows and columns of which are indexed
 by the domain elements; by default; these are ordered by orbits.</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">Consider the action of the symmetry group of the 3-cube on its vertices.
 We first calculate its decomposition into irreducible representations via<code>&gt; $g = cube_group(3); $a = $g-&gt;PERMUTATION_ACTION;</code><code>&gt; print irreducible_decomposition($a-&gt;CHARACTER, $g);</code><code> 1 0 0 1 0 0 0 0 1 1</code> We now calculate the projection matrices to the irreps number 3 and 8:<code>&gt; $p3 = isotypic_projector($g,$a,3); print $p3, "\n", rank($p3);</code><code> 1/8 -1/8 -1/8 1/8 -1/8 1/8 1/8 -1/8</code><code> -1/8 1/8 1/8 -1/8 1/8 -1/8 -1/8 1/8</code><code> -1/8 1/8 1/8 -1/8 1/8 -1/8 -1/8 1/8</code><code> 1/8 -1/8 -1/8 1/8 -1/8 1/8 1/8 -1/8</code><code> -1/8 1/8 1/8 -1/8 1/8 -1/8 -1/8 1/8</code><code> 1/8 -1/8 -1/8 1/8 -1/8 1/8 1/8 -1/8</code><code> 1/8 -1/8 -1/8 1/8 -1/8 1/8 1/8 -1/8</code><code> -1/8 1/8 1/8 -1/8 1/8 -1/8 -1/8 1/8</code><code> </code><code> 1</code><code>&gt; $p8 = isotypic_projector($g,$a,8); print $p8, "\n", rank($p8);</code><code> 3/8 -1/8 -1/8 -1/8 -1/8 -1/8 -1/8 3/8</code><code> -1/8 3/8 -1/8 -1/8 -1/8 -1/8 3/8 -1/8</code><code> -1/8 -1/8 3/8 -1/8 -1/8 3/8 -1/8 -1/8</code><code> -1/8 -1/8 -1/8 3/8 3/8 -1/8 -1/8 -1/8</code><code> -1/8 -1/8 -1/8 3/8 3/8 -1/8 -1/8 -1/8</code><code> -1/8 -1/8 3/8 -1/8 -1/8 3/8 -1/8 -1/8</code><code> -1/8 3/8 -1/8 -1/8 -1/8 -1/8 3/8 -1/8</code><code> 3/8 -1/8 -1/8 -1/8 -1/8 -1/8 -1/8 3/8</code><code> </code><code> 3</code> From this we deduce that the irrep indexed 3 has dimension 1, and the one indexed 8 has dimension 3.
 This is consistent with the information collected in the character table:<code>&gt; print $g-&gt;CHARACTER_TABLE-&gt;minor([3,8],All);</code><code> 1 1 1 -1 -1 -1 -1 1 1 -1</code><code> 3 1 0 -1 1 -1 0 -1 -1 3</code> In effect, the first entries in these rows are 1 and 3, respectively.</div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__85" onclick="swap_content('span:group__overload_1__85'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__85" onclick="swap_content('span:group__overload_1__85'); return false;"><b>isotypic_projector</b></a>
			&lt;Scalar&gt;
		 
			(G, A, i)  

			
				→ SparseMatrix&lt;QuadraticExtension&gt;<div style="display: inline" id="span:group__overload_1__85" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the projection map into the isotypic component given by the i-th irrep.
 Note that the option <em class="param">permute_to_orbit_order</em> makes no sense for matrix actions, so it is always set to 0.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">Scalar</td><td><div class="descr"><div>S the underlying number type</div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>the acting group</div></div></td></tr><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors&lt;Scalar&gt;</a></td><td class="param">A</td><td><div class="descr"><div>the action in question</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the sought irrep</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix&lt;QuadraticExtension&gt;</a></td><td><div class="descr"><div>pi the matrix of the projection</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">We first construct a matrix action:<code>&gt; $s = symmetric_group(3); $a = $s-&gt;REGULAR_REPRESENTATION;</code><code>&gt; print irreducible_decomposition($a-&gt;CHARACTER, $s);</code><code> 0 1 1</code> Since we now know that the irreps indexed 1 and 2 appear in the regular representation, we project to one of them:<code>&gt; print isotypic_projector($s, $a, 1);</code><code> 2/3 -1/3 -1/3</code><code> -1/3 2/3 -1/3</code><code> -1/3 -1/3 2/3</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__isotypic_supports__57" onclick="swap_content('span:group__isotypic_supports__57'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__isotypic_supports__57" onclick="swap_content('span:group__isotypic_supports__57'); return false;"><b>isotypic_supports</b></a>
			(a, A)  

			
				→ IncidenceMatrix<div style="display: inline" id="span:group__isotypic_supports__57" class="foldit"><br/><div class="descr_func"><div class="descr"><p> For each isotypic component of a representation <em class="param">a</em>, which of a given array <em class="param">A</em> of sets are supported on it?</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">a</td><td><div class="descr"><div>the representation in question</div></div></td></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Set&gt;</a></td><td class="param">A</td><td><div class="descr"><div>the given array of sets</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">permute_to_orbit_order</td><td><div class="descr"><div>Should the columns be ordered by orbits? Default 1</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__IncidenceMatrix__280" onclick="unfold('span:common__IncidenceMatrix__280');">IncidenceMatrix</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__overload_1__87" onclick="swap_content('span:group__overload_1__87'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__overload_1__87" onclick="swap_content('span:group__overload_1__87'); return false;"><b>isotypic_supports</b></a>
			(a, M)  

			
				→ IncidenceMatrix<div style="display: inline" id="span:group__overload_1__87" class="foldit"><br/><div class="descr_func"><div class="descr"><p> For each row of a given SparseMatrix <em class="param">M</em>, to which isotypic components of a representation <em class="param">a</em> does it have a non-zero projection?
 The columns of the SparseMatrix correspond, in order, to the sets of the representation.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">a</td><td><div class="descr"><div>the representation in question</div></div></td></tr><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td class="param">M</td><td><div class="descr"><div>the given matrix</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">permute_to_orbit_order</td><td><div class="descr"><div>Should the columns be ordered by orbits? Default 1</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__IncidenceMatrix__280" onclick="unfold('span:common__IncidenceMatrix__280');">IncidenceMatrix</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__lex_min_representative__46" onclick="swap_content('span:group__lex_min_representative__46'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__lex_min_representative__46" onclick="swap_content('span:group__lex_min_representative__46'); return false;"><b>lex_min_representative</b></a>
			(G, S)  

			
				→ Set<div style="display: inline" id="span:group__lex_min_representative__46" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes the lexicographically smallest representative of a given set with respect to a group</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">G</td><td><div class="descr"><div>a symmetry group</div></div></td></tr><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td class="param">S</td><td><div class="descr"><div>a set</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set</a></td><td><div class="descr"><div>the lex-min representative of S</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">To calculate the lex-min representative of the triangle [2,5,7] under the symmetry group of the 3-cube, type<code>&gt; print lex_min_representative(cube_group(3)-&gt;PERMUTATION_ACTION, new Set([2,5,7]));</code><code> {0 1 6}</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__partition_representatives__61" onclick="swap_content('span:group__partition_representatives__61'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__partition_representatives__61" onclick="swap_content('span:group__partition_representatives__61'); return false;"><b>partition_representatives</b></a>
			(gens, S)  

			
				→ Array&lt;Int&gt;<div style="display: inline" id="span:group__partition_representatives__61" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Partition a group into translates of a set stabilizer</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td class="param">gens</td><td><div class="descr"><div>the generators of a given group action</div></div></td></tr><tr><td><a href="common.html#common__Set__276" onclick="unfold('span:common__Set__276');">Set&lt;Int&gt;</a></td><td class="param">S</td><td><div class="descr"><div>a set</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__regular_representation__68" onclick="swap_content('span:group__regular_representation__68'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__regular_representation__68" onclick="swap_content('span:group__regular_representation__68'); return false;"><b>regular_representation</b></a>
			(a)  

			
				→ MatrixActionOnVectors<div style="display: inline" id="span:group__regular_representation__68" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the regular representation of a permutation action</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>a permutation action</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="#group__MatrixActionOnVectors__19" onclick="unfold('span:group__MatrixActionOnVectors__19');">MatrixActionOnVectors</a></td><td><div class="descr"><div>g the regular representation of <em class="param">a</em> by permutation matrices</div></div></td></tr></table></div><br/><div class="examples"><b>Example:</b><ul style="list-style-type:none"><li><div class="descr">To calculate the regular representation of the symmetric group S_3, type<code>&gt; $s = symmetric_group(3); $s-&gt;REGULAR_REPRESENTATION;</code><code>&gt; print $s-&gt;REGULAR_REPRESENTATION-&gt;properties();</code><code> type: MatrixActionOnVectors&lt;Rational&gt;</code><code> </code><code> GENERATORS</code><code> &lt;0 1 0</code><code> 1 0 0</code><code> 0 0 1</code><code> &gt;</code><code> &lt;1 0 0</code><code> 0 0 1</code><code> 0 1 0</code><code> &gt;</code><code> </code><code> </code><code> CONJUGACY_CLASS_REPRESENTATIVES</code><code> &lt;1 0 0</code><code> 0 1 0</code><code> 0 0 1</code><code> &gt;</code><code> &lt;0 1 0</code><code> 1 0 0</code><code> 0 0 1</code><code> &gt;</code><code> &lt;0 0 1</code><code> 1 0 0</code><code> 0 1 0</code><code> &gt;</code></div></li></ul></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__row_support_sizes__62" onclick="swap_content('span:group__row_support_sizes__62'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__row_support_sizes__62" onclick="swap_content('span:group__row_support_sizes__62'); return false;"><b>row_support_sizes</b></a>
			(M)  

			
				→ Array&lt;Int&gt;<div style="display: inline" id="span:group__row_support_sizes__62" class="foldit"><br/><div class="descr_func"><div class="descr"><p> How many non-zero entries are there in each row of a SparseMatrix?</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__SparseMatrix__308" onclick="unfold('span:common__SparseMatrix__308');">SparseMatrix</a></td><td class="param">M</td><td><div class="descr"><div>the given matrix</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__spans_invariant_subspace__48" onclick="swap_content('span:group__spans_invariant_subspace__48'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__spans_invariant_subspace__48" onclick="swap_content('span:group__spans_invariant_subspace__48'); return false;"><b>spans_invariant_subspace</b></a>
			(a, S)  

			
				→ Bool<div style="display: inline" id="span:group__spans_invariant_subspace__48" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Does a set <em class="param">S</em> of sparse vectors span an invariant subspace under an implicit group action <em class="param">a</em>?</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__ImplicitActionOnSets__18" onclick="unfold('span:group__ImplicitActionOnSets__18');">ImplicitActionOnSets</a></td><td class="param">a</td><td><div class="descr"><div>the given action</div></div></td></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;HashMap&lt;Bitset, Rational&gt;&gt;</a></td><td class="param">S</td><td><div class="descr"><div>the sparsely given generating vectors of the subspace</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">verbose</td><td><div class="descr"><div>give a certificate if the answer is False</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__span_same_subspace__47" onclick="swap_content('span:group__span_same_subspace__47'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__span_same_subspace__47" onclick="swap_content('span:group__span_same_subspace__47'); return false;"><b>span_same_subspace</b></a>
			(S1, S2)  

			
				→ Bool<div style="display: inline" id="span:group__span_same_subspace__47" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Do two collections <em class="param">S1</em>, <em class="param">S2</em> of sparse vectors span the same subspace?</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;HashMap&lt;SetType, Rational&gt;&gt;</a></td><td class="param">S1</td><td><div class="descr"><div>the sparse generating vectors of the first subspace</div></div></td></tr><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;HashMap&lt;SetType, Rational&gt;&gt;</a></td><td class="param">S2</td><td><div class="descr"><div>the sparse generating vectors of the second subspace</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__sparse_isotypic_basis__69" onclick="swap_content('span:group__sparse_isotypic_basis__69'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__sparse_isotypic_basis__69" onclick="swap_content('span:group__sparse_isotypic_basis__69'); return false;"><b>sparse_isotypic_basis</b></a>
			(rep, i)  

			
				→ Array&lt;HashMap&lt;Bitset,Rational&gt;&gt;<div style="display: inline" id="span:group__sparse_isotypic_basis__69" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate a sparse representation of a basis for an isotypic component.
 For this, the sets in the representation are listed in order by orbit. In this basis,
 the projection matrix to the isotypic component decomposes into blocks, one for each orbit.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">rep</td><td><div class="descr"><div>the given representation</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the irrep that defines the isotypic component</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__Bool__327" onclick="unfold('span:common__Bool__327');">Bool</a></td><td class="param">use_double</td><td><div class="descr"><div>use inexact arithmetic for reducing the basis; default 0</div></div></td></tr><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">filename</td><td><div class="descr"><div>if defined, the basis will be written to a file with this name, but not returned.
 Use this option if you expect very large output.</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;HashMap&lt;Bitset,Rational&gt;&gt;</a></td><td><div class="descr"><div>Basis. Each entry tells the coefficient for each orbit representative.</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__sparse_isotypic_spanning_set__59" onclick="swap_content('span:group__sparse_isotypic_spanning_set__59'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__sparse_isotypic_spanning_set__59" onclick="swap_content('span:group__sparse_isotypic_spanning_set__59'); return false;"><b>sparse_isotypic_spanning_set</b></a>
			(rep, i)  

			
				→ Array&lt;HashMap&lt;Bitset,Rational&gt;&gt;<div style="display: inline" id="span:group__sparse_isotypic_spanning_set__59" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate a sparse representation of a spanning set for an isotypic component.
 For this, the sets in the representation are listed in order by orbit. In this basis,
 the projection matrix to the isotypic component decomposes into blocks, one for each orbit.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">rep</td><td><div class="descr"><div>the given representation</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the irrep that defines the isotypic component</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">filename</td><td><div class="descr"><div>if defined, the basis will be written to a file with this name, but not returned.
 Use this option if you expect very large output.</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;HashMap&lt;Bitset,Rational&gt;&gt;</a></td><td><div class="descr"><div>SpanningSet. Each entry tells the coefficient for each orbit representative.</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__sparse_isotypic_support__53" onclick="swap_content('span:group__sparse_isotypic_support__53'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__sparse_isotypic_support__53" onclick="swap_content('span:group__sparse_isotypic_support__53'); return false;"><b>sparse_isotypic_support</b></a>
			(rep, i)  

			
				→ HashSet&lt;Bitset&gt;<div style="display: inline" id="span:group__sparse_isotypic_support__53" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Calculate the support of a sparse representation of a spanning set for an isotypic component.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationActionOnSets__21" onclick="unfold('span:group__PermutationActionOnSets__21');">PermutationActionOnSets</a></td><td class="param">rep</td><td><div class="descr"><div>the given representation</div></div></td></tr><tr><td><a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a></td><td class="param">i</td><td><div class="descr"><div>the index of the irrep that defines the isotypic component</div></div></td></tr></table><h5>Options</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td class="param">filename</td><td><div class="descr"><div>if defined, the basis will be written to a file with this name, but not returned.
 Use this option if you expect very large output.</div></div></td></tr></table><div class="descr"><div>Bool equivalence_class_only only report representatives of simplices, default true</div></div><table class="args"/><div class="descr"><div>Bool index_only only output the indices of the representatives to filename, default true</div></div><table class="args"/><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__HashSet__278" onclick="unfold('span:common__HashSet__278');">HashSet&lt;Bitset&gt;</a></td><td><div class="descr"><div>Support.</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__Utilities__11" onclick="swap_content('span:group__Utilities__11'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <div class="category">
              <h3>
                <a href="#" class="javalink" id="group__Utilities__11" onclick="swap_content('span:group__Utilities__11'); return false;">
                  <span class="category">Utilities</span>
                </a>
              </h3>
            </div>
            <div style="display: inline" id="span:group__Utilities__11" class="foldit">
              <div class="descr">
                <p> Miscellaneous functions.</p>
              </div>
              <ul class="unfoldable">
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__action__22" onclick="swap_content('span:group__action__22'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__action__22" onclick="swap_content('span:group__action__22'); return false;"><b>action</b></a>
			&lt;action_type&gt;
		 
			(g, O)  

			
				→ Object<div style="display: inline" id="span:group__action__22" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The image of an object <em class="param">O</em> under a group element <em class="param">g</em>.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">action_type</td><td><div class="descr"><div>one of: <a href="#group__on_container__7" onclick="unfold('span:group__on_container__7');">on_container</a>, <a href="#group__on_elements__9" onclick="unfold('span:group__on_elements__9');">on_elements</a>, <a href="#group__on_rows__5" onclick="unfold('span:group__on_rows__5');">on_rows</a>, <a href="#group__on_cols__6" onclick="unfold('span:group__on_cols__6');">on_cols</a>, <a href="#group__on_nonhomog_cols__8" onclick="unfold('span:group__on_nonhomog_cols__8');">on_nonhomog_cols</a></div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="#" onclick="unfold('span:');">Any</a></td><td class="param">g</td><td><div class="descr"><div>Group element</div></div></td></tr><tr><td><a href="core.html#core__Core__Object__7" onclick="unfold('span:core__Core__Object__7');">Object</a></td><td class="param">O</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="core.html#core__Core__Object__7" onclick="unfold('span:core__Core__Object__7');">Object</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__action_from_generators__24" onclick="swap_content('span:group__action_from_generators__24'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__action_from_generators__24" onclick="swap_content('span:group__action_from_generators__24'); return false;"><b>action_from_generators</b></a>
			(gens, action)  

			<div style="display: inline" id="span:group__action_from_generators__24" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Computes groups with a permutation action with the basic properties <a href="#group__BASE__96" onclick="unfold('span:group__BASE__96');">BASE</a>, 
 <a href="#group__STRONG_GENERATORS__95" onclick="unfold('span:group__STRONG_GENERATORS__95');">STRONG_GENERATORS</a>, and <a href="#group__TRANSVERSALS__93" onclick="unfold('span:group__TRANSVERSALS__93');">TRANSVERSALS</a>.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Array&lt;Int&gt;&gt;</a></td><td class="param">gens</td><td><div class="descr"><div>some generators of the group</div></div></td></tr><tr><td><a href="#group__Group__20" onclick="unfold('span:group__Group__20');">Group</a></td><td class="param">action</td><td><div class="descr"><div>the generated action</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__action_inv__26" onclick="swap_content('span:group__action_inv__26'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__action_inv__26" onclick="swap_content('span:group__action_inv__26'); return false;"><b>action_inv</b></a>
			&lt;action_type&gt;
		 
			(p, O)  

			
				→ Object<div style="display: inline" id="span:group__action_inv__26" class="foldit"><br/><div class="descr_func"><div class="descr"><p> The image of an object <em class="param">O</em> under the inverse of a
 permutation <em class="param">p</em>.</p></div></div><div class="level3"><h5>Type Parameters</h5><table class="args"><tr><td class="param">action_type</td><td><div class="descr"><div>one of: <a href="#group__on_container__7" onclick="unfold('span:group__on_container__7');">on_container</a>, <a href="#group__on_elements__9" onclick="unfold('span:group__on_elements__9');">on_elements</a>, <a href="#group__on_rows__5" onclick="unfold('span:group__on_rows__5');">on_rows</a>, <a href="#group__on_cols__6" onclick="unfold('span:group__on_cols__6');">on_cols</a>, <a href="#group__on_nonhomog_cols__8" onclick="unfold('span:group__on_nonhomog_cols__8');">on_nonhomog_cols</a></div></div></td></tr></table><h5>Parameters</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array&lt;Int&gt;</a></td><td class="param">p</td><td><div class="descr"><div>permutation</div></div></td></tr><tr><td><a href="core.html#core__Core__Object__7" onclick="unfold('span:core__Core__Object__7');">Object</a></td><td class="param">O</td><td/></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="core.html#core__Core__Object__7" onclick="unfold('span:core__Core__Object__7');">Object</a></td><td/></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__action_to_cyclic_notation__25" onclick="swap_content('span:group__action_to_cyclic_notation__25'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__action_to_cyclic_notation__25" onclick="swap_content('span:group__action_to_cyclic_notation__25'); return false;"><b>action_to_cyclic_notation</b></a>
			(a)  

			
				→ String<div style="display: inline" id="span:group__action_to_cyclic_notation__25" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Returns group generators in 1-based cyclic notation
 (GAP like, not permlib like notation)</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>the action of the permutation group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__String__323" onclick="unfold('span:common__String__323');">String</a></td><td><div class="descr"><div>group generators, separated by newline and comma</div></div></td></tr></table></div></div></div>
                  </div>
                </li>
                <li>
                  <div class="li">
                    <div class="icon" id="icon:group__all_group_elements__23" onclick="swap_content('span:group__all_group_elements__23'); return false;">
		 	
	</div>
                    <div class="unfoldable"><a href="#" class="javalink" id="group__all_group_elements__23" onclick="swap_content('span:group__all_group_elements__23'); return false;"><b>all_group_elements</b></a>
			(a)  

			
				→ Array<div style="display: inline" id="span:group__all_group_elements__23" class="foldit"><br/><div class="descr_func"><div class="descr"><p> Compute all elements of a given group, expressed as a permutation action.</p></div></div><div class="level3"><h5>Parameters</h5><table class="args"><tr><td><a href="#group__PermutationAction__15" onclick="unfold('span:group__PermutationAction__15');">PermutationAction</a></td><td class="param">a</td><td><div class="descr"><div>the action of a permutation group</div></div></td></tr></table><h5>Returns</h5><table class="args"><tr><td><a href="common.html#common__Array__319" onclick="unfold('span:common__Array__319');">Array</a></td><td><div class="descr"><div>&lt;Array&lt;Int&gt; all group elements </div></div></td></tr></table></div></div></div>
                  </div>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </li>
    </ul>
  </div>
  <div class="level3">
    <h2>Property Types</h2>
    <ul class="unfoldable">
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_cols__6" onclick="swap_content('span:group__on_cols__6'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_cols__6" onclick="swap_content('span:group__on_cols__6'); return false;">
              <b>on_cols</b>
            </a>
            <div style="display: inline" id="span:group__on_cols__6" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on the columns of a matrix.</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_container__7" onclick="swap_content('span:group__on_container__7'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_container__7" onclick="swap_content('span:group__on_container__7'); return false;">
              <b>on_container</b>
            </a>
            <div style="display: inline" id="span:group__on_container__7" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on the given container. It will permute the order of
 the elements</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_elements__9" onclick="swap_content('span:group__on_elements__9'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_elements__9" onclick="swap_content('span:group__on_elements__9'); return false;">
              <b>on_elements</b>
            </a>
            <div style="display: inline" id="span:group__on_elements__9" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on the deepest elements inside a given container,
 which should be of type <a href="common.html#common__Int__318" onclick="unfold('span:common__Int__318');">Int</a>.</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_nonhomog_cols__8" onclick="swap_content('span:group__on_nonhomog_cols__8'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_nonhomog_cols__8" onclick="swap_content('span:group__on_nonhomog_cols__8'); return false;">
              <b>on_nonhomog_cols</b>
            </a>
            <div style="display: inline" id="span:group__on_nonhomog_cols__8" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on all columns of a matrix, except the '0'-th one,
 and adjusting the indices of the permutation</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_nonhomog_container__10" onclick="swap_content('span:group__on_nonhomog_container__10'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_nonhomog_container__10" onclick="swap_content('span:group__on_nonhomog_container__10'); return false;">
              <b>on_nonhomog_container</b>
            </a>
            <div style="display: inline" id="span:group__on_nonhomog_container__10" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on the given container. It will permute the order of
 the elements, leaving the '0'-th one fixed and adjusting the indices of the permutation</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
      <li>
        <div class="li">
          <div class="icon" id="icon:group__on_rows__5" onclick="swap_content('span:group__on_rows__5'); return false;">
		 	
	</div>
          <div class="unfoldable">
            <a href="#" class="javalink" id="group__on_rows__5" onclick="swap_content('span:group__on_rows__5'); return false;">
              <b>on_rows</b>
            </a>
            <div style="display: inline" id="span:group__on_rows__5" class="foldit">
              <div class="descr">
                <p> A template parameter used by <a href="#group__action__22" onclick="unfold('span:group__action__22');">action</a> and <a href="#group__orbit__34" onclick="unfold('span:group__orbit__34');">orbit</a> specifying that
 the permutation acts on the rows of a matrix.</p>
              </div>
              <div class="level3"/>
            </div>
          </div>
        </div>
      </li>
    </ul>
  </div>
</div>
